diff --git a/.buckconfig b/.buckconfig
deleted file mode 100644
index 934256c..0000000
--- a/.buckconfig
+++ /dev/null
@@ -1,6 +0,0 @@
-
-[android]
- target = Google Inc.:Google APIs:23
-
-[maven_repositories]
- central = https://repo1.maven.org/maven2
diff --git a/.eslintrc.js b/.eslintrc.js
deleted file mode 100644
index 1896997..0000000
--- a/.eslintrc.js
+++ /dev/null
@@ -1,6 +0,0 @@
-module.exports = {
- root: true,
- extends: '@react-native-community',
- parser: '@typescript-eslint/parser',
- plugins: ['@typescript-eslint'],
-};
diff --git a/.gitattributes b/.gitattributes
deleted file mode 100644
index d42ff18..0000000
--- a/.gitattributes
+++ /dev/null
@@ -1 +0,0 @@
-*.pbxproj -text
diff --git a/.gitignore b/.gitignore
index 6a5e410..df88839 100644
--- a/.gitignore
+++ b/.gitignore
@@ -28,6 +28,7 @@ build/
.gradle
local.properties
*.iml
+*.hprof
# Visual Studio Code
#
@@ -60,4 +61,4 @@ buck-out/
*.jsbundle
# CocoaPods
-/ios/Pods/
+/ios/Pods/
\ No newline at end of file
diff --git a/.prettierrc.js b/.prettierrc.js
deleted file mode 100644
index 9ef4f0d..0000000
--- a/.prettierrc.js
+++ /dev/null
@@ -1,9 +0,0 @@
-module.exports = {
- bracketSpacing: true,
- jsxBracketSameLine: true,
- singleQuote: true,
- trailingComma: 'all',
- semi: true,
- tabWidth: 2,
- printWidth: 80,
-};
diff --git a/.watchmanconfig b/.watchmanconfig
deleted file mode 100644
index 9e26dfe..0000000
--- a/.watchmanconfig
+++ /dev/null
@@ -1 +0,0 @@
-{}
\ No newline at end of file
diff --git a/App.tsx b/App.tsx
index 3483681..d665913 100644
--- a/App.tsx
+++ b/App.tsx
@@ -1,11 +1,11 @@
-import React from 'react';
-import { Provider } from 'react-redux';
-import store from 'redux/store';
-import NavigatorView from 'navigations/RootNavigation';
-import { theme, ThemeProvider } from 'components/styles/theme';
+import React from "react";
+import { Provider } from "react-redux";
+import store from "redux/store";
+import NavigatorView from "navigations/RootNavigation";
+import { theme, ThemeProvider } from "components/styles/theme";
if (__DEV__) {
- import('./ReactotronConfig').then(() => console.log('Reactotron Configured'));
+ import("./ReactotronConfig").then(() => console.log("Reactotron Configured"));
}
const App = () => {
diff --git a/Gemfile b/Gemfile
new file mode 100644
index 0000000..2c3edcf
--- /dev/null
+++ b/Gemfile
@@ -0,0 +1,6 @@
+source 'https://rubygems.org'
+
+# You may use http://rbenv.org/ or https://rvm.io/ to install and use this version
+ruby '2.7.4'
+
+gem 'cocoapods', '~> 1.11', '>= 1.11.2'
diff --git a/Gemfile.lock b/Gemfile.lock
new file mode 100644
index 0000000..5628351
--- /dev/null
+++ b/Gemfile.lock
@@ -0,0 +1,100 @@
+GEM
+ remote: https://rubygems.org/
+ specs:
+ CFPropertyList (3.0.5)
+ rexml
+ activesupport (6.1.5)
+ concurrent-ruby (~> 1.0, >= 1.0.2)
+ i18n (>= 1.6, < 2)
+ minitest (>= 5.1)
+ tzinfo (~> 2.0)
+ zeitwerk (~> 2.3)
+ addressable (2.8.0)
+ public_suffix (>= 2.0.2, < 5.0)
+ algoliasearch (1.27.5)
+ httpclient (~> 2.8, >= 2.8.3)
+ json (>= 1.5.1)
+ atomos (0.1.3)
+ claide (1.1.0)
+ cocoapods (1.11.3)
+ addressable (~> 2.8)
+ claide (>= 1.0.2, < 2.0)
+ cocoapods-core (= 1.11.3)
+ cocoapods-deintegrate (>= 1.0.3, < 2.0)
+ cocoapods-downloader (>= 1.4.0, < 2.0)
+ cocoapods-plugins (>= 1.0.0, < 2.0)
+ cocoapods-search (>= 1.0.0, < 2.0)
+ cocoapods-trunk (>= 1.4.0, < 2.0)
+ cocoapods-try (>= 1.1.0, < 2.0)
+ colored2 (~> 3.1)
+ escape (~> 0.0.4)
+ fourflusher (>= 2.3.0, < 3.0)
+ gh_inspector (~> 1.0)
+ molinillo (~> 0.8.0)
+ nap (~> 1.0)
+ ruby-macho (>= 1.0, < 3.0)
+ xcodeproj (>= 1.21.0, < 2.0)
+ cocoapods-core (1.11.3)
+ activesupport (>= 5.0, < 7)
+ addressable (~> 2.8)
+ algoliasearch (~> 1.0)
+ concurrent-ruby (~> 1.1)
+ fuzzy_match (~> 2.0.4)
+ nap (~> 1.0)
+ netrc (~> 0.11)
+ public_suffix (~> 4.0)
+ typhoeus (~> 1.0)
+ cocoapods-deintegrate (1.0.5)
+ cocoapods-downloader (1.6.3)
+ cocoapods-plugins (1.0.0)
+ nap
+ cocoapods-search (1.0.1)
+ cocoapods-trunk (1.6.0)
+ nap (>= 0.8, < 2.0)
+ netrc (~> 0.11)
+ cocoapods-try (1.2.0)
+ colored2 (3.1.2)
+ concurrent-ruby (1.1.10)
+ escape (0.0.4)
+ ethon (0.15.0)
+ ffi (>= 1.15.0)
+ ffi (1.15.5)
+ fourflusher (2.3.1)
+ fuzzy_match (2.0.4)
+ gh_inspector (1.1.3)
+ httpclient (2.8.3)
+ i18n (1.10.0)
+ concurrent-ruby (~> 1.0)
+ json (2.6.1)
+ minitest (5.15.0)
+ molinillo (0.8.0)
+ nanaimo (0.3.0)
+ nap (1.1.0)
+ netrc (0.11.0)
+ public_suffix (4.0.7)
+ rexml (3.2.5)
+ ruby-macho (2.5.1)
+ typhoeus (1.4.0)
+ ethon (>= 0.9.0)
+ tzinfo (2.0.4)
+ concurrent-ruby (~> 1.0)
+ xcodeproj (1.21.0)
+ CFPropertyList (>= 2.3.3, < 4.0)
+ atomos (~> 0.1.3)
+ claide (>= 1.0.2, < 2.0)
+ colored2 (~> 3.1)
+ nanaimo (~> 0.3.0)
+ rexml (~> 3.2.4)
+ zeitwerk (2.5.4)
+
+PLATFORMS
+ ruby
+
+DEPENDENCIES
+ cocoapods (~> 1.11, >= 1.11.2)
+
+RUBY VERSION
+ ruby 2.7.4p191
+
+BUNDLED WITH
+ 2.2.27
diff --git a/README.md b/README.md
index dc91d54..68066e4 100644
--- a/README.md
+++ b/README.md
@@ -1 +1,34 @@
-# react-native-starter
+## Starter
+
+Building APK key
+
+```
+
+yarn install
+mkdir -p android/app/src/main/assets
+yarn clean:android && rm -rf android/app/build
+npx react-native bundle --platform android --dev false --entry-file index.js --bundle-output android/app/src/main/assets/index.android.bundle --assets-dest android/app/src/main/res
+cd android && ./gradlew clean assembleRelease && cd ../
+
+```
+
+You can find the build here : `/android/app/build/outputs/apk/release`
+
+### Or if you want to generate AAP instead
+
+cd android && ./gradlew bundleRelease && cd ../
+
+### Testing the release build of your app
+
+npx react-native run-android --variant=release
+
+### Fix some ios bugs
+
+cd ios && rm Podfile.lock && pod deintegrate && pod install && cd .. && yarn clean:ios
+// pas nécessaire a priori … nécessaire pour build
+npx react-native bundle --entry-file='index.js' --bundle-output='./ios/main.jsbundle' --dev=false --platform='ios' --assets-dest ios
+yarn ios
+
+```
+
+```
diff --git a/android/app/_BUCK b/android/app/_BUCK
index 4983b6a..4e34199 100644
--- a/android/app/_BUCK
+++ b/android/app/_BUCK
@@ -35,12 +35,12 @@ android_library(
android_build_config(
name = "build_config",
- package = "com.bes",
+ package = "com.reactnativestarter",
)
android_resource(
name = "res",
- package = "com.bes",
+ package = "com.reactnativestarter",
res = "src/main/res",
)
diff --git a/android/app/src/debug/AndroidManifest.xml b/android/app/src/debug/AndroidManifest.xml
index fa26aa5..4b185bc 100644
--- a/android/app/src/debug/AndroidManifest.xml
+++ b/android/app/src/debug/AndroidManifest.xml
@@ -4,5 +4,10 @@
-
+
+
+
diff --git a/android/app/src/debug/java/com/bes/ReactNativeFlipper.java b/android/app/src/debug/java/com/reactnativestarter/ReactNativeFlipper.java
similarity index 94%
rename from android/app/src/debug/java/com/bes/ReactNativeFlipper.java
rename to android/app/src/debug/java/com/reactnativestarter/ReactNativeFlipper.java
index d670abd..150e68b 100644
--- a/android/app/src/debug/java/com/bes/ReactNativeFlipper.java
+++ b/android/app/src/debug/java/com/reactnativestarter/ReactNativeFlipper.java
@@ -1,10 +1,10 @@
/**
- * Copyright (c) Facebook, Inc. and its affiliates.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
*
*
This source code is licensed under the MIT license found in the LICENSE file in the root
* directory of this source tree.
*/
-package com.bes;
+package com.reactnativestarter;
import android.content.Context;
import com.facebook.flipper.android.AndroidFlipperClient;
@@ -19,6 +19,7 @@
import com.facebook.flipper.plugins.network.NetworkFlipperPlugin;
import com.facebook.flipper.plugins.react.ReactFlipperPlugin;
import com.facebook.flipper.plugins.sharedpreferences.SharedPreferencesFlipperPlugin;
+import com.facebook.react.ReactInstanceEventListener;
import com.facebook.react.ReactInstanceManager;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.modules.network.NetworkingModule;
@@ -51,7 +52,7 @@ public void apply(OkHttpClient.Builder builder) {
ReactContext reactContext = reactInstanceManager.getCurrentReactContext();
if (reactContext == null) {
reactInstanceManager.addReactInstanceEventListener(
- new ReactInstanceManager.ReactInstanceEventListener() {
+ new ReactInstanceEventListener() {
@Override
public void onReactContextInitialized(ReactContext reactContext) {
reactInstanceManager.removeReactInstanceEventListener(this);
diff --git a/android/app/src/main/AndroidManifest.xml b/android/app/src/main/AndroidManifest.xml
index e1c48a2..89cf968 100644
--- a/android/app/src/main/AndroidManifest.xml
+++ b/android/app/src/main/AndroidManifest.xml
@@ -1,5 +1,5 @@
+ package="com.reactnativestarter">
@@ -9,20 +9,18 @@
android:icon="@mipmap/ic_launcher"
android:roundIcon="@mipmap/ic_launcher_round"
android:allowBackup="false"
- android:usesCleartextTraffic="true"
android:theme="@style/AppTheme">
+ android:windowSoftInputMode="adjustResize"
+ android:exported="true">
-
-
diff --git a/android/app/src/main/assets/fonts/SegoeUI.ttf b/android/app/src/main/assets/fonts/SegoeUI.ttf
new file mode 100644
index 0000000..4e98f11
Binary files /dev/null and b/android/app/src/main/assets/fonts/SegoeUI.ttf differ
diff --git a/android/app/src/main/assets/fonts/SegoeUISB.ttf b/android/app/src/main/assets/fonts/SegoeUISB.ttf
new file mode 100644
index 0000000..4d344e7
Binary files /dev/null and b/android/app/src/main/assets/fonts/SegoeUISB.ttf differ
diff --git a/android/app/src/main/assets/index.android.bundle b/android/app/src/main/assets/index.android.bundle
deleted file mode 100644
index 6db1ea5..0000000
--- a/android/app/src/main/assets/index.android.bundle
+++ /dev/null
@@ -1,1013 +0,0 @@
-var __BUNDLE_START_TIME__=this.nativePerformanceNow?nativePerformanceNow():Date.now(),__DEV__=false,process=this.process||{};process.env=process.env||{};process.env.NODE_ENV=process.env.NODE_ENV||"production";
-!(function(r){"use strict";r.__r=o,r.__d=function(r,i,n){if(null!=e[i])return;var o={dependencyMap:n,factory:r,hasError:!1,importedAll:t,importedDefault:t,isInitialized:!1,publicModule:{exports:{}}};e[i]=o},r.__c=n,r.__registerSegment=function(r,e){s[r]=e};var e=n(),t={},i={}.hasOwnProperty;function n(){return e=Object.create(null)}function o(r){var t=r,i=e[t];return i&&i.isInitialized?i.publicModule.exports:d(t,i)}function l(r){var i=r;if(e[i]&&e[i].importedDefault!==t)return e[i].importedDefault;var n=o(i),l=n&&n.__esModule?n.default:n;return e[i].importedDefault=l}function u(r){var n=r;if(e[n]&&e[n].importedAll!==t)return e[n].importedAll;var l,u=o(n);if(u&&u.__esModule)l=u;else{if(l={},u)for(var a in u)i.call(u,a)&&(l[a]=u[a]);l.default=u}return e[n].importedAll=l}o.importDefault=l,o.importAll=u;var a=!1;function d(e,t){if(!a&&r.ErrorUtils){var i;a=!0;try{i=v(e,t)}catch(e){r.ErrorUtils.reportFatalError(e)}return a=!1,i}return v(e,t)}var c=16,f=65535;function p(r){return{segmentId:r>>>c,localId:r&f}}o.unpackModuleId=p,o.packModuleId=function(r){return(r.segmentId<0){var n=p(t),a=n.segmentId,d=n.localId,c=s[a];null!=c&&(c(d),i=e[t])}var f=r.nativeRequire;if(!i&&f){var v=p(t),h=v.segmentId;f(v.localId,h),i=e[t]}if(!i)throw Error('Requiring unknown module "'+t+'".');if(i.hasError)throw m(t,i.error);i.isInitialized=!0;var I=i,_=I.factory,g=I.dependencyMap;try{var w=i.publicModule;return w.id=t,_(r,o,l,u,w,w.exports,g),i.factory=void 0,i.dependencyMap=void 0,w.exports}catch(r){throw i.hasError=!0,i.error=r,i.isInitialized=!1,i.publicModule.exports=void 0,r}}function m(r,e){return Error('Requiring module "'+r+'", which threw an exception: '+e)}})('undefined'!=typeof global?global:'undefined'!=typeof window?window:this);
-!(function(n){var e=(function(){function n(n,e){return n}function e(n){var e={};return n.forEach(function(n,r){e[n]=!0}),e}function r(n,r,u){if(n.formatValueCalls++,n.formatValueCalls>200)return"[TOO BIG formatValueCalls "+n.formatValueCalls+" exceeded limit of 200]";var f=t(n,r);if(f)return f;var c=Object.keys(r),s=e(c);if(d(r)&&(c.indexOf('message')>=0||c.indexOf('description')>=0))return o(r);if(0===c.length){if(v(r)){var g=r.name?': '+r.name:'';return n.stylize('[Function'+g+']','special')}if(p(r))return n.stylize(RegExp.prototype.toString.call(r),'regexp');if(y(r))return n.stylize(Date.prototype.toString.call(r),'date');if(d(r))return o(r)}var h,m,b='',j=!1,O=['{','}'];(h=r,Array.isArray(h)&&(j=!0,O=['[',']']),v(r))&&(b=' [Function'+(r.name?': '+r.name:'')+']');return p(r)&&(b=' '+RegExp.prototype.toString.call(r)),y(r)&&(b=' '+Date.prototype.toUTCString.call(r)),d(r)&&(b=' '+o(r)),0!==c.length||j&&0!=r.length?u<0?p(r)?n.stylize(RegExp.prototype.toString.call(r),'regexp'):n.stylize('[Object]','special'):(n.seen.push(r),m=j?i(n,r,u,s,c):c.map(function(e){return a(n,r,u,s,e,j)}),n.seen.pop(),l(m,b,O)):O[0]+b+O[1]}function t(n,e){if(s(e))return n.stylize('undefined','undefined');if('string'==typeof e){var r="'"+JSON.stringify(e).replace(/^"|"$/g,'').replace(/'/g,"\\'").replace(/\\"/g,'"')+"'";return n.stylize(r,'string')}return c(e)?n.stylize(''+e,'number'):u(e)?n.stylize(''+e,'boolean'):f(e)?n.stylize('null','null'):void 0}function o(n){return'['+Error.prototype.toString.call(n)+']'}function i(n,e,r,t,o){for(var i=[],l=0,u=e.length;l-1&&(u=a?u.split('\n').map(function(n){return' '+n}).join('\n').substr(2):'\n'+u.split('\n').map(function(n){return' '+n}).join('\n')):u=n.stylize('[Circular]','special')),s(l)){if(a&&i.match(/^\d+$/))return u;(l=JSON.stringify(''+i)).match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/)?(l=l.substr(1,l.length-2),l=n.stylize(l,'name')):(l=l.replace(/'/g,"\\'").replace(/\\"/g,'"').replace(/(^"|"$)/g,"'"),l=n.stylize(l,'string'))}return l+': '+u}function l(n,e,r){return n.reduce(function(n,e){return 0,e.indexOf('\n')>=0&&0,n+e.replace(/\u001b\[\d\d?m/g,'').length+1},0)>60?r[0]+(''===e?'':e+'\n ')+' '+n.join(',\n ')+' '+r[1]:r[0]+e+' '+n.join(', ')+' '+r[1]}function u(n){return'boolean'==typeof n}function f(n){return null===n}function c(n){return'number'==typeof n}function s(n){return void 0===n}function p(n){return g(n)&&'[object RegExp]'===h(n)}function g(n){return'object'==typeof n&&null!==n}function y(n){return g(n)&&'[object Date]'===h(n)}function d(n){return g(n)&&('[object Error]'===h(n)||n instanceof Error)}function v(n){return'function'==typeof n}function h(n){return Object.prototype.toString.call(n)}function m(n,e){return Object.prototype.hasOwnProperty.call(n,e)}return function(e,t){return r({seen:[],formatValueCalls:0,stylize:n},e,t.depth)}})(),r='(index)',t={trace:0,info:1,warn:2,error:3},o=[];o[t.trace]='debug',o[t.info]='log',o[t.warn]='warning',o[t.error]='error';var i=1;function a(r){return function(){var a;a=1===arguments.length&&'string'==typeof arguments[0]?arguments[0]:Array.prototype.map.call(arguments,function(n){return e(n,{depth:10})}).join(', ');var l=arguments[0],u=r;'string'==typeof l&&'Warning: '===l.slice(0,9)&&u>=t.error&&(u=t.warn),n.__inspectorLog&&n.__inspectorLog(o[u],a,[].slice.call(arguments),i),s.length&&(a=p('',a)),n.nativeLoggingHook(a,u)}}function l(n,e){return Array.apply(null,Array(e)).map(function(){return n})}var u="\u2502",f="\u2510",c="\u2518",s=[];function p(n,e){return s.join('')+n+' '+(e||'')}if(n.nativeLoggingHook){n.console;n.console={error:a(t.error),info:a(t.info),log:a(t.info),warn:a(t.warn),trace:a(t.trace),debug:a(t.trace),table:function(e){if(!Array.isArray(e)){var o=e;for(var i in e=[],o)if(o.hasOwnProperty(i)){var a=o[i];a[r]=i,e.push(a)}}if(0!==e.length){var u=Object.keys(e[0]).sort(),f=[],c=[];u.forEach(function(n,r){c[r]=n.length;for(var t=0;t';return function(){for(var n=arguments.length,l=new Array(n),a=0;a0?s[s.length-1]:null,h=s.length>1?s[s.length-2]:null,y='function'==typeof v,C='function'==typeof h;C&&u(y,'Cannot have a non-function arg after a function arg.');var M=y?v:null,b=C?h:null,p=y+C;if(s=s.slice(0,s.length-p),'sync'===l)return o.callNativeSyncHook(n,t,s,b,M);o.enqueueNativeCall(n,t,s,b,M)}).type=l,f}function c(n,t){return-1!==n.indexOf(t)}function v(t,o){return n(o,t||{})}g.__fbGenNativeModule=l;var h={};if(g.nativeModuleProxy)h=g.nativeModuleProxy;else if(!g.nativeExtensions){var y=g.__fbBatchedBridgeConfig;u(y,'__fbBatchedBridgeConfig is not set, cannot invoke native modules');var C=r(d[4]);(y.remoteModuleConfig||[]).forEach(function(n,t){var o=l(n,t);o&&(o.module?h[o.name]=o.module:C(h,o.name,{get:function(){return f(o.name,t)}}))})}m.exports=h},13,[14,15,21,3,33]);
-__d(function(g,r,i,a,m,e,d){function t(){return m.exports=t=Object.assign||function(t){for(var n=1;nn.length)&&(t=n.length);for(var l=0,o=new Array(t);l=5){var c=this._queue;this._queue=[[],[],[],this._callID],this._lastFlush=o,g.nativeFlushQueueImmediate(c)}n.counterEvent('pending_js_to_native_queue',this._queue[0].length),this.__spy&&this.__spy({type:1,module:t+'',method:l,args:u})}},{key:"createDebugLookup",value:function(t,l,u){}},{key:"setImmediatesCallback",value:function(t){this._immediatesCallback=t}},{key:"__guard",value:function(t){if(this.__shouldPauseOnThrow())t();else try{t()}catch(t){s.reportFatalError(t)}}},{key:"__shouldPauseOnThrow",value:function(){return'undefined'!=typeof DebuggerInternal&&!0===DebuggerInternal.shouldPauseOnThrow}},{key:"__callImmediates",value:function(){n.beginEvent('JSTimers.callImmediates()'),null!=this._immediatesCallback&&this._immediatesCallback(),n.endEvent()}},{key:"__callFunction",value:function(t,l,u){this._lastFlush=Date.now(),this._eventLoopStartTime=this._lastFlush,this.__spy?n.beginEvent(t+"."+l+"("+o(u)+")"):n.beginEvent(t+"."+l+"(...)"),this.__spy&&this.__spy({type:0,module:t,method:l,args:u});var s=this.getCallableModule(t);h(!!s,'Module %s is not a registered callable module (calling %s)',t,l),h(!!s[l],'Method %s does not exist on module %s',l,t),s[l].apply(s,u),n.endEvent()}},{key:"__invokeCallback",value:function(l,u){this._lastFlush=Date.now(),this._eventLoopStartTime=this._lastFlush;var s=l>>>1,n=1&l?this._successCallbacks.get(s):this._failureCallbacks.get(s);n&&(this._successCallbacks.delete(s),this._failureCallbacks.delete(s),n.apply(void 0,t(u)))}}],[{key:"spy",value:function(t){c.prototype.__spy=!0===t?function(t){console.log((0===t.type?'N->JS':'JS->N')+" : "+(t.module?t.module+'.':'')+t.method+"("+JSON.stringify(t.args)+")")}:!1===t?null:t}}]),c})());m.exports=c},22,[23,27,28,29,30,31,3,32,4]);
-__d(function(g,r,i,a,m,e,d){var n=r(d[0]),t=r(d[1]),o=r(d[2]),u=r(d[3]);m.exports=function(c){return n(c)||t(c)||o(c)||u()}},23,[24,25,18,26]);
-__d(function(g,r,i,a,m,e,d){var n=r(d[0]);m.exports=function(t){if(Array.isArray(t))return n(t)}},24,[19]);
-__d(function(g,r,i,a,m,e,d){m.exports=function(n){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(n))return Array.from(n)}},25,[]);
-__d(function(g,r,i,a,m,e,d){m.exports=function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}},26,[]);
-__d(function(g,r,i,a,m,e,d){m.exports=function(n,o){if(!(n instanceof o))throw new TypeError("Cannot call a class as a function")}},27,[]);
-__d(function(g,r,i,a,m,e,d){function n(n,t){for(var o=0;o=t.length?{done:!0}:{done:!1,value:t[f++]}}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}return(o=t[Symbol.iterator]()).next.bind(o)}function u(t,n){if(t){if("string"==typeof t)return f(t,n);var o=Object.prototype.toString.call(t).slice(8,-1);return"Object"===o&&t.constructor&&(o=t.constructor.name),"Map"===o||"Set"===o?Array.from(t):"Arguments"===o||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(o)?f(t,n):void 0}}function f(t,n){(null==n||n>t.length)&&(n=t.length);for(var o=0,u=new Array(n);oc+"...(truncated)...".length?u.substring(0,c)+"...(truncated)...":u}if('object'!=typeof u||null===u)return u;var l=u;if(Array.isArray(u))b.length>=f?l="[ ... array with "+u.length+" values ... ]":u.length>y&&(l=u.slice(0,y).concat(["... extra "+(u.length-y)+" values truncated ..."]));else{(0,n.default)('object'==typeof u,'This was already found earlier');var s=Object.keys(u);if(b.length>=f)l="{ ... object with "+s.length+" keys ... }";else if(s.length>v){l={};for(var h,I=o(s.slice(0,v));!(h=I()).done;){var p=h.value;l[p]=u[p]}l['...(truncated keys)...']=s.length-v}}return b.unshift(l),l}return function(t){if(void 0===t)return'undefined';if(null===t)return'null';if('function'==typeof t)try{return t.toString()}catch(t){return'[function unknown]'}else{if(t instanceof Error)return t.name+': '+t.message;try{var n=JSON.stringify(t,I);return void 0===n?'["'+typeof t+'" failed to stringify]':n}catch(n){if('function'==typeof t.toString)try{return t.toString()}catch(t){}}}return'["'+typeof t+'" failed to stringify]'}}var c=l({maxDepth:10,maxStringLimit:100,maxArrayLimit:50,maxObjectKeysLimit:50});e.default=c},32,[8,3]);
-__d(function(g,r,i,a,m,e,d){'use strict';m.exports=function(t,n,u){var b,c=u.get,o=!1!==u.enumerable,f=!1!==u.writable,l=!1;function s(u){b=u,l=!0,Object.defineProperty(t,n,{value:u,configurable:!0,enumerable:o,writable:f})}Object.defineProperty(t,n,{get:function(){return l||(l=!0,s(c())),b},set:s,configurable:!0,enumerable:o})}},33,[]);
-__d(function(g,r,i,a,m,e,d){'use strict';var t=r(d[0]),n=r(d[1]),c=r(d[2]),o=r(d[3]),s=r(d[4]),u=r(d[5]);function l(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(t){return!1}}var f=r(d[6]),p=r(d[7]),h=(function(h){o(R,f);var v,y,b=(v=R,y=l(),function(){var t,n=u(v);if(y){var c=u(this).constructor;t=Reflect.construct(n,arguments,c)}else t=n.apply(this,arguments);return s(this,t)});function R(){var n;t(this,R);var c=new p;return(n=b.call(this,c)).sharedSubscriber=c,n}return n(R,[{key:"addListener",value:function(t,n,o){return c(u(R.prototype),"addListener",this).call(this,t,n,o)}},{key:"removeAllListeners",value:function(t){c(u(R.prototype),"removeAllListeners",this).call(this,t)}},{key:"removeSubscription",value:function(t){t.emitter!==this?t.emitter.removeSubscription(t):c(u(R.prototype),"removeSubscription",this).call(this,t)}}]),R})();m.exports=new h},34,[27,28,35,38,40,37,42,45]);
-__d(function(g,r,i,a,m,e,d){var t=r(d[0]);function n(c,f,o){return"undefined"!=typeof Reflect&&Reflect.get?m.exports=n=Reflect.get:m.exports=n=function(n,c,f){var o=t(n,c);if(o){var u=Object.getOwnPropertyDescriptor(o,c);return u.get?u.get.call(f):u.value}},n(c,f,o||c)}m.exports=n},35,[36]);
-__d(function(g,r,i,a,m,e,d){var t=r(d[0]);m.exports=function(n,o){for(;!Object.prototype.hasOwnProperty.call(n,o)&&null!==(n=t(n)););return n}},36,[37]);
-__d(function(g,r,i,a,m,e,d){function t(o){return m.exports=t=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)},t(o)}m.exports=t},37,[]);
-__d(function(g,r,i,a,m,e,d){var t=r(d[0]);m.exports=function(o,n){if("function"!=typeof n&&null!==n)throw new TypeError("Super expression must either be null or a function");o.prototype=Object.create(n&&n.prototype,{constructor:{value:o,writable:!0,configurable:!0}}),n&&t(o,n)}},38,[39]);
-__d(function(g,r,i,a,m,e,d){function t(o,n){return m.exports=t=Object.setPrototypeOf||function(t,o){return t.__proto__=o,t},t(o,n)}m.exports=t},39,[]);
-__d(function(g,r,i,a,m,e,d){var n=r(d[0]),t=r(d[1]);m.exports=function(o,c){return!c||"object"!==n(c)&&"function"!=typeof c?t(o):c}},40,[11,41]);
-__d(function(g,r,i,a,m,e,d){m.exports=function(n){if(void 0===n)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return n}},41,[]);
-__d(function(g,r,i,a,m,e,d){'use strict';var t=r(d[0]),n=r(d[1]),s=r(d[2]),u=r(d[3]),o=r(d[4]),c=function(){return!0},b=(function(){function b(n){t(this,b),this._subscriber=n||new u}return n(b,[{key:"addListener",value:function(t,n,u){return this._subscriber.addSubscription(t,new s(this,this._subscriber,n,u))}},{key:"once",value:function(t,n,s){var u=this;return this.addListener(t,function(){u.removeCurrentListener();for(var t=arguments.length,o=new Array(t),c=0;c=0||Object.prototype.propertyIsEnumerable.call(n,l)&&(b[l]=n[l])}return b}},55,[56]);
-__d(function(g,r,i,a,m,e,d){m.exports=function(n,t){if(null==n)return{};var f,u,o={},c=Object.keys(n);for(u=0;u=0||(o[f]=n[f]);return o}},56,[]);
-__d(function(g,r,i,a,m,e,d){'use strict';m.exports=r(d[0])},57,[58]);
-__d(function(g,r,i,a,m,e,d){'use strict';var t=r(d[0]),n="function"==typeof Symbol&&Symbol.for,o=n?Symbol.for("react.element"):60103,u=n?Symbol.for("react.portal"):60106,f=n?Symbol.for("react.fragment"):60107,c=n?Symbol.for("react.strict_mode"):60108,l=n?Symbol.for("react.profiler"):60114,s=n?Symbol.for("react.provider"):60109,p=n?Symbol.for("react.context"):60110,y=n?Symbol.for("react.forward_ref"):60112,v=n?Symbol.for("react.suspense"):60113,h=n?Symbol.for("react.memo"):60115,b=n?Symbol.for("react.lazy"):60116,_="function"==typeof Symbol&&Symbol.iterator;function S(t){for(var n="https://reactjs.org/docs/error-decoder.html?invariant="+t,o=1;oF.length&&F.push(t)}function D(t,n,f,c){var l=typeof t;"undefined"!==l&&"boolean"!==l||(t=null);var s=!1;if(null===t)s=!0;else switch(l){case"string":case"number":s=!0;break;case"object":switch(t.$$typeof){case o:case u:s=!0}}if(s)return f(c,t,""===n?"."+B(t,0):n),1;if(s=0,n=""===n?".":n+":",Array.isArray(t))for(var p=0;p1&&(o-=1),o<.16666666666666666?l+6*(n-l)*o:o<.5?n:o<.6666666666666666?l+(n-l)*(.6666666666666666-o)*6:l}function n(n,o,t){var u=t<.5?t*(1+o):t+o-t*o,s=2*t-u,h=l(s,u,n+.3333333333333333),c=l(s,u,n),b=l(s,u,n-.3333333333333333);return Math.round(255*h)<<24|Math.round(255*c)<<16|Math.round(255*b)<<8}var o,t='[-+]?\\d*\\.?\\d+',u="[-+]?\\d*\\.?\\d+%";function s(){for(var l=arguments.length,n=new Array(l),o=0;o255?255:n}function c(l){return(parseFloat(l)%360+360)%360/360}function b(l){var n=parseFloat(l);return n<0?0:n>1?255:Math.round(255*n)}function p(l){var n=parseFloat(l);return n<0?0:n>100?1:n/100}var y={transparent:0,aliceblue:4042850303,antiquewhite:4209760255,aqua:16777215,aquamarine:2147472639,azure:4043309055,beige:4126530815,bisque:4293182719,black:255,blanchedalmond:4293643775,blue:65535,blueviolet:2318131967,brown:2771004159,burlywood:3736635391,burntsienna:3934150143,cadetblue:1604231423,chartreuse:2147418367,chocolate:3530104575,coral:4286533887,cornflowerblue:1687547391,cornsilk:4294499583,crimson:3692313855,cyan:16777215,darkblue:35839,darkcyan:9145343,darkgoldenrod:3095792639,darkgray:2846468607,darkgreen:6553855,darkgrey:2846468607,darkkhaki:3182914559,darkmagenta:2332068863,darkolivegreen:1433087999,darkorange:4287365375,darkorchid:2570243327,darkred:2332033279,darksalmon:3918953215,darkseagreen:2411499519,darkslateblue:1211993087,darkslategray:793726975,darkslategrey:793726975,darkturquoise:13554175,darkviolet:2483082239,deeppink:4279538687,deepskyblue:12582911,dimgray:1768516095,dimgrey:1768516095,dodgerblue:512819199,firebrick:2988581631,floralwhite:4294635775,forestgreen:579543807,fuchsia:4278255615,gainsboro:3705462015,ghostwhite:4177068031,gold:4292280575,goldenrod:3668254975,gray:2155905279,green:8388863,greenyellow:2919182335,grey:2155905279,honeydew:4043305215,hotpink:4285117695,indianred:3445382399,indigo:1258324735,ivory:4294963455,khaki:4041641215,lavender:3873897215,lavenderblush:4293981695,lawngreen:2096890111,lemonchiffon:4294626815,lightblue:2916673279,lightcoral:4034953471,lightcyan:3774873599,lightgoldenrodyellow:4210742015,lightgray:3553874943,lightgreen:2431553791,lightgrey:3553874943,lightpink:4290167295,lightsalmon:4288707327,lightseagreen:548580095,lightskyblue:2278488831,lightslategray:2005441023,lightslategrey:2005441023,lightsteelblue:2965692159,lightyellow:4294959359,lime:16711935,limegreen:852308735,linen:4210091775,magenta:4278255615,maroon:2147483903,mediumaquamarine:1724754687,mediumblue:52735,mediumorchid:3126187007,mediumpurple:2473647103,mediumseagreen:1018393087,mediumslateblue:2070474495,mediumspringgreen:16423679,mediumturquoise:1221709055,mediumvioletred:3340076543,midnightblue:421097727,mintcream:4127193855,mistyrose:4293190143,moccasin:4293178879,navajowhite:4292783615,navy:33023,oldlace:4260751103,olive:2155872511,olivedrab:1804477439,orange:4289003775,orangered:4282712319,orchid:3664828159,palegoldenrod:4008225535,palegreen:2566625535,paleturquoise:2951671551,palevioletred:3681588223,papayawhip:4293907967,peachpuff:4292524543,peru:3448061951,pink:4290825215,plum:3718307327,powderblue:2967529215,purple:2147516671,rebeccapurple:1714657791,red:4278190335,rosybrown:3163525119,royalblue:1097458175,saddlebrown:2336560127,salmon:4202722047,sandybrown:4104413439,seagreen:780883967,seashell:4294307583,sienna:2689740287,silver:3233857791,skyblue:2278484991,slateblue:1784335871,slategray:1887473919,slategrey:1887473919,snow:4294638335,springgreen:16744447,steelblue:1182971135,tan:3535047935,teal:8421631,thistle:3636451583,tomato:4284696575,turquoise:1088475391,violet:4001558271,wheat:4125012991,white:4294967295,whitesmoke:4126537215,yellow:4294902015,yellowgreen:2597139199};m.exports=function(l){var f,k=(void 0===o&&(o={rgb:new RegExp('rgb'+s(t,t,t)),rgba:new RegExp('rgba'+s(t,t,t,t)),hsl:new RegExp('hsl'+s(t,u,u)),hsla:new RegExp('hsla'+s(t,u,u,t)),hex3:/^#([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex4:/^#([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#([0-9a-fA-F]{6})$/,hex8:/^#([0-9a-fA-F]{8})$/}),o);return'number'==typeof l?l>>>0===l&&l>=0&&l<=4294967295?l:null:'object'==typeof l&&null!=l&&null!=(0,r(d[0]).normalizeColorObject)(l)?l:'string'!=typeof l?null:(f=k.hex6.exec(l))?parseInt(f[1]+'ff',16)>>>0:y.hasOwnProperty(l)?y[l]:(f=k.rgb.exec(l))?(h(f[1])<<24|h(f[2])<<16|h(f[3])<<8|255)>>>0:(f=k.rgba.exec(l))?(h(f[1])<<24|h(f[2])<<16|h(f[3])<<8|b(f[4]))>>>0:(f=k.hex3.exec(l))?parseInt(f[1]+f[1]+f[2]+f[2]+f[3]+f[3]+'ff',16)>>>0:(f=k.hex8.exec(l))?parseInt(f[1],16)>>>0:(f=k.hex4.exec(l))?parseInt(f[1]+f[1]+f[2]+f[2]+f[3]+f[3]+f[4]+f[4],16)>>>0:(f=k.hsl.exec(l))?(255|n(c(f[1]),p(f[2]),p(f[3])))>>>0:(f=k.hsla.exec(l))?(n(c(f[1]),p(f[2]),p(f[3]))|b(f[4]))>>>0:null}},68,[69]);
-__d(function(g,r,i,a,m,e,d){'use strict';Object.defineProperty(e,"__esModule",{value:!0}),e.processColorObject=e.normalizeColorObject=e.ColorAndroidPrivate=e.PlatformColor=void 0;e.PlatformColor=function(){for(var o=arguments.length,t=new Array(o),n=0;n3?p-3:0),l=3;l
>>8)>>>0,o|=0)}}},79,[51,68,69]);
-__d(function(g,r,i,a,m,e,d){'use strict';r(d[0]),r(d[1]),r(d[2]),r(d[3]).default;m.exports=function(t){return t}},80,[81,51,3,32]);
-__d(function(g,r,i,a,m,e,d){'use strict';var t=r(d[0]),n=r(d[1]),o={createIdentityMatrix:function(){return[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]},createCopy:function(t){return[t[0],t[1],t[2],t[3],t[4],t[5],t[6],t[7],t[8],t[9],t[10],t[11],t[12],t[13],t[14],t[15]]},createOrthographic:function(t,n,o,u,s,c){return[2/(n-t),0,0,0,0,2/(u-o),0,0,0,0,-2/(c-s),0,-(n+t)/(n-t),-(u+o)/(u-o),-(c+s)/(c-s),1]},createFrustum:function(t,n,o,u,s,c){var v=1/(n-t),f=1/(u-o),h=1/(s-c);return[s*v*2,0,0,0,0,s*f*2,0,0,(n+t)*v,(u+o)*f,(c+s)*h,-1,0,0,c*s*h*2,0]},createPerspective:function(t,n,o,u){var s=1/Math.tan(t/2),c=1/(o-u);return[s/n,0,0,0,0,s,0,0,0,0,(u+o)*c,-1,0,0,u*o*c*2,0]},createTranslate2d:function(t,n){var u=o.createIdentityMatrix();return o.reuseTranslate2dCommand(u,t,n),u},reuseTranslate2dCommand:function(t,n,o){t[12]=n,t[13]=o},reuseTranslate3dCommand:function(t,n,o,u){t[12]=n,t[13]=o,t[14]=u},createScale:function(t){var n=o.createIdentityMatrix();return o.reuseScaleCommand(n,t),n},reuseScaleCommand:function(t,n){t[0]=n,t[5]=n},reuseScale3dCommand:function(t,n,o,u){t[0]=n,t[5]=o,t[10]=u},reusePerspectiveCommand:function(t,n){t[11]=-1/n},reuseScaleXCommand:function(t,n){t[0]=n},reuseScaleYCommand:function(t,n){t[5]=n},reuseScaleZCommand:function(t,n){t[10]=n},reuseRotateXCommand:function(t,n){t[5]=Math.cos(n),t[6]=Math.sin(n),t[9]=-Math.sin(n),t[10]=Math.cos(n)},reuseRotateYCommand:function(t,n){t[0]=Math.cos(n),t[2]=-Math.sin(n),t[8]=Math.sin(n),t[10]=Math.cos(n)},reuseRotateZCommand:function(t,n){t[0]=Math.cos(n),t[1]=Math.sin(n),t[4]=-Math.sin(n),t[5]=Math.cos(n)},createRotateZ:function(t){var n=o.createIdentityMatrix();return o.reuseRotateZCommand(n,t),n},reuseSkewXCommand:function(t,n){t[4]=Math.tan(n)},reuseSkewYCommand:function(t,n){t[1]=Math.tan(n)},multiplyInto:function(t,n,o){var u=n[0],s=n[1],c=n[2],v=n[3],f=n[4],h=n[5],M=n[6],l=n[7],C=n[8],p=n[9],x=n[10],T=n[11],y=n[12],S=n[13],D=n[14],P=n[15],q=o[0],X=o[1],Y=o[2],I=o[3];t[0]=q*u+X*f+Y*C+I*y,t[1]=q*s+X*h+Y*p+I*S,t[2]=q*c+X*M+Y*x+I*D,t[3]=q*v+X*l+Y*T+I*P,q=o[4],X=o[5],Y=o[6],I=o[7],t[4]=q*u+X*f+Y*C+I*y,t[5]=q*s+X*h+Y*p+I*S,t[6]=q*c+X*M+Y*x+I*D,t[7]=q*v+X*l+Y*T+I*P,q=o[8],X=o[9],Y=o[10],I=o[11],t[8]=q*u+X*f+Y*C+I*y,t[9]=q*s+X*h+Y*p+I*S,t[10]=q*c+X*M+Y*x+I*D,t[11]=q*v+X*l+Y*T+I*P,q=o[12],X=o[13],Y=o[14],I=o[15],t[12]=q*u+X*f+Y*C+I*y,t[13]=q*s+X*h+Y*p+I*S,t[14]=q*c+X*M+Y*x+I*D,t[15]=q*v+X*l+Y*T+I*P},determinant:function(n){var o=t(n,16),u=o[0],s=o[1],c=o[2],v=o[3],f=o[4],h=o[5],M=o[6],l=o[7],C=o[8],p=o[9],x=o[10],T=o[11],y=o[12],S=o[13],D=o[14],P=o[15];return v*M*p*y-c*l*p*y-v*h*x*y+s*l*x*y+c*h*T*y-s*M*T*y-v*M*C*S+c*l*C*S+v*f*x*S-u*l*x*S-c*f*T*S+u*M*T*S+v*h*C*D-s*l*C*D-v*f*p*D+u*l*p*D+s*f*T*D-u*h*T*D-c*h*C*P+s*M*C*P+c*f*p*P-u*M*p*P-s*f*x*P+u*h*x*P},inverse:function(n){var u=o.determinant(n);if(!u)return n;var s=t(n,16),c=s[0],v=s[1],f=s[2],h=s[3],M=s[4],l=s[5],C=s[6],p=s[7],x=s[8],T=s[9],y=s[10],S=s[11],D=s[12],P=s[13],q=s[14],X=s[15];return[(C*S*P-p*y*P+p*T*q-l*S*q-C*T*X+l*y*X)/u,(h*y*P-f*S*P-h*T*q+v*S*q+f*T*X-v*y*X)/u,(f*p*P-h*C*P+h*l*q-v*p*q-f*l*X+v*C*X)/u,(h*C*T-f*p*T-h*l*y+v*p*y+f*l*S-v*C*S)/u,(p*y*D-C*S*D-p*x*q+M*S*q+C*x*X-M*y*X)/u,(f*S*D-h*y*D+h*x*q-c*S*q-f*x*X+c*y*X)/u,(h*C*D-f*p*D-h*M*q+c*p*q+f*M*X-c*C*X)/u,(f*p*x-h*C*x+h*M*y-c*p*y-f*M*S+c*C*S)/u,(l*S*D-p*T*D+p*x*P-M*S*P-l*x*X+M*T*X)/u,(h*T*D-v*S*D-h*x*P+c*S*P+v*x*X-c*T*X)/u,(v*p*D-h*l*D+h*M*P-c*p*P-v*M*X+c*l*X)/u,(h*l*x-v*p*x-h*M*T+c*p*T+v*M*S-c*l*S)/u,(C*T*D-l*y*D-C*x*P+M*y*P+l*x*q-M*T*q)/u,(v*y*D-f*T*D+f*x*P-c*y*P-v*x*q+c*T*q)/u,(f*l*D-v*C*D-f*M*P+c*C*P+v*M*q-c*l*q)/u,(v*C*x-f*l*x+f*M*T-c*C*T-v*M*y+c*l*y)/u]},transpose:function(t){return[t[0],t[4],t[8],t[12],t[1],t[5],t[9],t[13],t[2],t[6],t[10],t[14],t[3],t[7],t[11],t[15]]},multiplyVectorByMatrix:function(n,o){var u=t(n,4),s=u[0],c=u[1],v=u[2],f=u[3];return[s*o[0]+c*o[4]+v*o[8]+f*o[12],s*o[1]+c*o[5]+v*o[9]+f*o[13],s*o[2]+c*o[6]+v*o[10]+f*o[14],s*o[3]+c*o[7]+v*o[11]+f*o[15]]},v3Length:function(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2])},v3Normalize:function(t,n){var u=1/(n||o.v3Length(t));return[t[0]*u,t[1]*u,t[2]*u]},v3Dot:function(t,n){return t[0]*n[0]+t[1]*n[1]+t[2]*n[2]},v3Combine:function(t,n,o,u){return[o*t[0]+u*n[0],o*t[1]+u*n[1],o*t[2]+u*n[2]]},v3Cross:function(t,n){return[t[1]*n[2]-t[2]*n[1],t[2]*n[0]-t[0]*n[2],t[0]*n[1]-t[1]*n[0]]},quaternionToDegreesXYZ:function(n,u,s){var c=t(n,4),v=c[0],f=c[1],h=c[2],M=c[3],l=v*v,C=f*f,p=h*h,x=v*f+h*M,T=M*M+l+C+p,y=180/Math.PI;return x>.49999*T?[0,2*Math.atan2(v,M)*y,90]:x<-.49999*T?[0,-2*Math.atan2(v,M)*y,-90]:[o.roundTo3Places(Math.atan2(2*v*M-2*f*h,1-2*l-2*p)*y),o.roundTo3Places(Math.atan2(2*f*M-2*v*h,1-2*C-2*p)*y),o.roundTo3Places(Math.asin(2*v*f+2*h*M)*y)]},roundTo3Places:function(t){var n=t.toString().split('e');return.001*Math.round(n[0]+'e'+(n[1]?+n[1]-3:3))},decomposeMatrix:function(t){n(16===t.length,'Matrix decomposition needs a list of 3d matrix values, received %s',t);var u=[],s=[],c=[],v=[],f=[];if(t[15]){for(var h=[],M=[],l=0;l<4;l++){h.push([]);for(var C=0;C<4;C++){var p=t[4*l+C]/t[15];h[l].push(p),M.push(3===C?0:p)}}if(M[15]=1,o.determinant(M)){if(0!==h[0][3]||0!==h[1][3]||0!==h[2][3]){var x=[h[0][3],h[1][3],h[2][3],h[3][3]],T=o.inverse(M),y=o.transpose(T);u=o.multiplyVectorByMatrix(x,y)}else u[0]=u[1]=u[2]=0,u[3]=1;for(var S=0;S<3;S++)f[S]=h[3][S];for(var D=[],P=0;P<3;P++)D[P]=[h[P][0],h[P][1],h[P][2]];c[0]=o.v3Length(D[0]),D[0]=o.v3Normalize(D[0],c[0]),v[0]=o.v3Dot(D[0],D[1]),D[1]=o.v3Combine(D[1],D[0],1,-v[0]),v[0]=o.v3Dot(D[0],D[1]),D[1]=o.v3Combine(D[1],D[0],1,-v[0]),c[1]=o.v3Length(D[1]),D[1]=o.v3Normalize(D[1],c[1]),v[0]/=c[1],v[1]=o.v3Dot(D[0],D[2]),D[2]=o.v3Combine(D[2],D[0],1,-v[1]),v[2]=o.v3Dot(D[1],D[2]),D[2]=o.v3Combine(D[2],D[1],1,-v[2]),c[2]=o.v3Length(D[2]),D[2]=o.v3Normalize(D[2],c[2]),v[1]/=c[2],v[2]/=c[2];var q,X=o.v3Cross(D[1],D[2]);if(o.v3Dot(D[0],X)<0)for(var Y=0;Y<3;Y++)c[Y]*=-1,D[Y][0]*=-1,D[Y][1]*=-1,D[Y][2]*=-1;return s[0]=.5*Math.sqrt(Math.max(1+D[0][0]-D[1][1]-D[2][2],0)),s[1]=.5*Math.sqrt(Math.max(1-D[0][0]+D[1][1]-D[2][2],0)),s[2]=.5*Math.sqrt(Math.max(1-D[0][0]-D[1][1]+D[2][2],0)),s[3]=.5*Math.sqrt(Math.max(1+D[0][0]+D[1][1]+D[2][2],0)),D[2][1]>D[1][2]&&(s[0]=-s[0]),D[0][2]>D[2][0]&&(s[1]=-s[1]),D[1][0]>D[0][1]&&(s[2]=-s[2]),{rotationDegrees:q=s[0]<.001&&s[0]>=0&&s[1]<.001&&s[1]>=0?[0,0,o.roundTo3Places(180*Math.atan2(D[0][1],D[0][0])/Math.PI)]:o.quaternionToDegreesXYZ(s,h,D),perspective:u,quaternion:s,scale:c,skew:v,translation:f,rotate:q[2],rotateX:q[0],rotateY:q[1],scaleX:c[0],scaleY:c[1],translateX:f[0],translateY:f[1]}}}}};m.exports=o},81,[15,3]);
-__d(function(g,r,i,a,m,e,d){'use strict';var t={width:void 0,height:void 0};m.exports=function(h,n){return(h=h||t)!==(n=n||t)&&(h.width!==n.width||h.height!==n.height)}},82,[]);
-__d(function(g,r,i,a,m,e,d){'use strict';var t=r(d[0]),n=r(d[1]),u=(r(d[2]),r(d[3]),r(d[4]),r(d[5]),(function(){function u(){t(this,u)}return n(u,null,[{key:"validateStyleProp",value:function(t,n,u){}},{key:"validateStyle",value:function(t,n){}},{key:"addValidStylePropTypes",value:function(t){}}]),u})());m.exports=u},83,[27,28,66,77,78,3]);
-__d(function(g,r,i,a,m,e,d){'use strict';m.exports=function t(n){if(null!==n&&'object'==typeof n){if(!Array.isArray(n))return n;for(var f={},o=0,u=n.length;o1?u-1:0),c=1;cthis.eventPool.length&&this.eventPool.push(e)}function Q(e){e.eventPool=[],e.getPooled=D,e.release=F}o(U.prototype,{preventDefault:function(){this.defaultPrevented=!0;var e=this.nativeEvent;e&&(e.preventDefault?e.preventDefault():"unknown"!=typeof e.returnValue&&(e.returnValue=!1),this.isDefaultPrevented=M)},stopPropagation:function(){var e=this.nativeEvent;e&&(e.stopPropagation?e.stopPropagation():"unknown"!=typeof e.cancelBubble&&(e.cancelBubble=!0),this.isPropagationStopped=M)},persist:function(){this.isPersistent=M},isPersistent:A,destructor:function(){var e,t=this.constructor.Interface;for(e in t)this[e]=null;this.nativeEvent=this._targetInst=this.dispatchConfig=null,this.isPropagationStopped=this.isDefaultPrevented=A,this._dispatchInstances=this._dispatchListeners=null}}),U.Interface={type:null,target:null,currentTarget:function(){return null},eventPhase:null,bubbles:null,cancelable:null,timeStamp:function(e){return e.timeStamp||Date.now()},defaultPrevented:null,isTrusted:null},U.extend=function(e){function t(){}function n(){return r.apply(this,arguments)}var r=this;t.prototype=r.prototype;var i=new t;return o(i,n.prototype),n.prototype=i,n.prototype.constructor=n,n.Interface=o({},r.Interface,e),n.extend=r.extend,Q(n),n},Q(U);var O=U.extend({touchHistory:function(){return null}});function j(e){return"topTouchStart"===e}function H(e){return"topTouchMove"===e}var W=["topTouchStart"],L=["topTouchMove"],B=["topTouchCancel","topTouchEnd"],V=[],Y={touchBank:V,numberActiveTouches:0,indexOfSingleActiveTouch:-1,mostRecentTimeStamp:0};function q(e){return e.timeStamp||e.timestamp}function X(e){if(null==(e=e.identifier))throw Error("Touch object is missing identifier.");return e}function $(e){var t=X(e),n=V[t];n?(n.touchActive=!0,n.startPageX=e.pageX,n.startPageY=e.pageY,n.startTimeStamp=q(e),n.currentPageX=e.pageX,n.currentPageY=e.pageY,n.currentTimeStamp=q(e),n.previousPageX=e.pageX,n.previousPageY=e.pageY,n.previousTimeStamp=q(e)):(n={touchActive:!0,startPageX:e.pageX,startPageY:e.pageY,startTimeStamp:q(e),currentPageX:e.pageX,currentPageY:e.pageY,currentTimeStamp:q(e),previousPageX:e.pageX,previousPageY:e.pageY,previousTimeStamp:q(e)},V[t]=n),Y.mostRecentTimeStamp=q(e)}function K(e){var t=V[X(e)];t&&(t.touchActive=!0,t.previousPageX=t.currentPageX,t.previousPageY=t.currentPageY,t.previousTimeStamp=t.currentTimeStamp,t.currentPageX=e.pageX,t.currentPageY=e.pageY,t.currentTimeStamp=q(e),Y.mostRecentTimeStamp=q(e))}function G(e){var t=V[X(e)];t&&(t.touchActive=!1,t.previousPageX=t.currentPageX,t.previousPageY=t.currentPageY,t.previousTimeStamp=t.currentTimeStamp,t.currentPageX=e.pageX,t.currentPageY=e.pageY,t.currentTimeStamp=q(e),Y.mostRecentTimeStamp=q(e))}var J={recordTouchTrack:function(e,t){if(H(e))t.changedTouches.forEach(K);else if(j(e))t.changedTouches.forEach($),Y.numberActiveTouches=t.touches.length,1===Y.numberActiveTouches&&(Y.indexOfSingleActiveTouch=t.touches[0].identifier);else if(("topTouchEnd"===e||"topTouchCancel"===e)&&(t.changedTouches.forEach(G),Y.numberActiveTouches=t.touches.length,1===Y.numberActiveTouches))for(e=0;ea||(l=a),Re(l,e,i)}}}),x=function(e){return be.get(e._nativeTag)||null},E=Te,S=function(e){var t=(e=e.stateNode)._nativeTag;if(void 0===t&&(t=(e=e.canonical)._nativeTag),!t)throw Error("All native instances should have a tag.");return e},ie.injection.injectGlobalResponderHandler({onChange:function(e,t,n){null!==t?u.UIManager.setJSResponder(t.stateNode._nativeTag,n):u.UIManager.clearJSResponder()}});var _e=s.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED;_e.hasOwnProperty("ReactCurrentDispatcher")||(_e.ReactCurrentDispatcher={current:null}),_e.hasOwnProperty("ReactCurrentBatchConfig")||(_e.ReactCurrentBatchConfig={suspense:null});var Ce="function"==typeof Symbol&&Symbol.for,Ne=Ce?Symbol.for("react.element"):60103,ze=Ce?Symbol.for("react.portal"):60106,Ie=Ce?Symbol.for("react.fragment"):60107,Me=Ce?Symbol.for("react.strict_mode"):60108,Ae=Ce?Symbol.for("react.profiler"):60114,Ue=Ce?Symbol.for("react.provider"):60109,De=Ce?Symbol.for("react.context"):60110,Fe=Ce?Symbol.for("react.concurrent_mode"):60111,Qe=Ce?Symbol.for("react.forward_ref"):60112,Oe=Ce?Symbol.for("react.suspense"):60113,je=Ce?Symbol.for("react.suspense_list"):60120,He=Ce?Symbol.for("react.memo"):60115,We=Ce?Symbol.for("react.lazy"):60116,Le=Ce?Symbol.for("react.block"):60121,Be="function"==typeof Symbol&&Symbol.iterator;function Ve(e){return null===e||"object"!=typeof e?null:"function"==typeof(e=Be&&e[Be]||e["@@iterator"])?e:null}function Ye(e){if(-1===e._status){var t=e._result;t||(t=e._ctor),t=t(),e._status=0,e._result=t,t.then(function(t){0===e._status&&(t=t.default,e._status=1,e._result=t)},function(t){0===e._status&&(e._status=2,e._result=t)})}}function qe(e){if(null==e)return null;if("function"==typeof e)return e.displayName||e.name||null;if("string"==typeof e)return e;switch(e){case Ie:return"Fragment";case ze:return"Portal";case Ae:return"Profiler";case Me:return"StrictMode";case Oe:return"Suspense";case je:return"SuspenseList"}if("object"==typeof e)switch(e.$$typeof){case De:return(e.displayName||"Context")+".Consumer";case Ue:return(e._context.displayName||"Context")+".Provider";case Qe:var t=e.render;return t=t.displayName||t.name||"",e.displayName||(""!==t?"ForwardRef("+t+")":"ForwardRef");case He:return qe(e.type);case Le:return qe(e.render);case We:if(e=1===e._status?e._result:null)return qe(e)}return null}function Xe(e){var t=e,n=e;if(e.alternate)for(;t.return;)t=t.return;else{e=t;do{0!=(1026&(t=e).effectTag)&&(n=t.return),e=t.return}while(e)}return 3===t.tag?n:null}function $e(e){if(Xe(e)!==e)throw Error("Unable to find node on an unmounted component.")}function Ke(e){var t=e.alternate;if(!t){if(null===(t=Xe(e)))throw Error("Unable to find node on an unmounted component.");return t!==e?null:e}for(var n=e,r=t;;){var i=n.return;if(null===i)break;var l=i.alternate;if(null===l){if(null!==(r=i.return)){n=r;continue}break}if(i.child===l.child){for(l=i.child;l;){if(l===n)return $e(i),e;if(l===r)return $e(i),t;l=l.sibling}throw Error("Unable to find node on an unmounted component.")}if(n.return!==r.return)n=i,r=l;else{for(var a=!1,o=i.child;o;){if(o===n){a=!0,n=i,r=l;break}if(o===r){a=!0,r=i,n=l;break}o=o.sibling}if(!a){for(o=l.child;o;){if(o===n){a=!0,n=l,r=i;break}if(o===r){a=!0,r=l,n=i;break}o=o.sibling}if(!a)throw Error("Child was not found in either parent set. This indicates a bug in React related to the return pointer. Please file an issue.")}}if(n.alternate!==r)throw Error("Return fibers should always be each others' alternates. This error is likely caused by a bug in React. Please file an issue.")}if(3!==n.tag)throw Error("Unable to find node on an unmounted component.");return n.stateNode.current===n?e:t}function Ge(e){if(!(e=Ke(e)))return null;for(var t=e;;){if(5===t.tag||6===t.tag)return t;if(t.child)t.child.return=t,t=t.child;else{if(t===e)break;for(;!t.sibling;){if(!t.return||t.return===e)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}}return null}var Je={},Ze=null,et=0,tt={unsafelyIgnoreFunctions:!0};function nt(e,t){return"object"!=typeof t||null===t||u.deepDiffer(e,t,tt)}function rt(e,t,n){if(Array.isArray(t))for(var r=t.length;r--&&0Tt||(e.current=bt[Tt],bt[Tt]=null,Tt--)}function Et(e,t){bt[++Tt]=e.current,e.current=t}var St={},wt={current:St},kt={current:!1},Pt=St;function Rt(e,t){var n=e.type.contextTypes;if(!n)return St;var r=e.stateNode;if(r&&r.__reactInternalMemoizedUnmaskedChildContext===t)return r.__reactInternalMemoizedMaskedChildContext;var i,l={};for(i in n)l[i]=t[i];return r&&((e=e.stateNode).__reactInternalMemoizedUnmaskedChildContext=t,e.__reactInternalMemoizedMaskedChildContext=l),l}function _t(e){return null!==(e=e.childContextTypes)&&void 0!==e}function Ct(){xt(kt),xt(wt)}function Nt(e,t,n){if(wt.current!==St)throw Error("Unexpected context found on stack. This error is likely caused by a bug in React. Please file an issue.");Et(wt,t),Et(kt,n)}function zt(e,t,n){var r=e.stateNode;if(e=t.childContextTypes,"function"!=typeof r.getChildContext)return n;for(var i in r=r.getChildContext())if(!(i in e))throw Error((qe(t)||"Unknown")+'.getChildContext(): key "'+i+'" is not defined in childContextTypes.');return o({},n,{},r)}function It(e){return e=(e=e.stateNode)&&e.__reactInternalMemoizedMergedChildContext||St,Pt=wt.current,Et(wt,e),Et(kt,kt.current),!0}function Mt(e,t,n){var r=e.stateNode;if(!r)throw Error("Expected to have an instance by this point. This error is likely caused by a bug in React. Please file an issue.");n?(e=zt(e,t,Pt),r.__reactInternalMemoizedMergedChildContext=e,xt(kt),xt(wt),Et(wt,e)):xt(kt),Et(kt,n)}var At=c.unstable_runWithPriority,Ut=c.unstable_scheduleCallback,Dt=c.unstable_cancelCallback,Ft=c.unstable_requestPaint,Qt=c.unstable_now,Ot=c.unstable_getCurrentPriorityLevel,jt=c.unstable_ImmediatePriority,Ht=c.unstable_UserBlockingPriority,Wt=c.unstable_NormalPriority,Lt=c.unstable_LowPriority,Bt=c.unstable_IdlePriority,Vt={},Yt=c.unstable_shouldYield,qt=void 0!==Ft?Ft:function(){},Xt=null,$t=null,Kt=!1,Gt=Qt(),Jt=1e4>Gt?Qt:function(){return Qt()-Gt};function Zt(){switch(Ot()){case jt:return 99;case Ht:return 98;case Wt:return 97;case Lt:return 96;case Bt:return 95;default:throw Error("Unknown priority level.")}}function en(e){switch(e){case 99:return jt;case 98:return Ht;case 97:return Wt;case 96:return Lt;case 95:return Bt;default:throw Error("Unknown priority level.")}}function tn(e,t){return e=en(e),At(e,t)}function nn(e,t,n){return e=en(e),Ut(e,t,n)}function rn(e){return null===Xt?(Xt=[e],$t=Ut(jt,an)):Xt.push(e),Vt}function ln(){if(null!==$t){var e=$t;$t=null,Dt(e)}an()}function an(){if(!Kt&&null!==Xt){Kt=!0;var e=0;try{var t=Xt;tn(99,function(){for(;e=t&&(Or=!0),e.firstContext=null)}function xn(e,t){if(gn!==e&&!1!==t&&0!==t)if("number"==typeof t&&1073741823!==t||(gn=e,t=1073741823),t={context:e,observedBits:t,next:null},null===mn){if(null===hn)throw Error("Context can only be read while React is rendering. In classes, you can read it in the render method or getDerivedStateFromProps. In function components, you can read it directly in the function body, but not inside Hooks like useReducer() or useMemo().");mn=t,hn.dependencies={expirationTime:0,firstContext:t,responders:null}}else mn=mn.next=t;return e._currentValue}var En=!1;function Sn(e){e.updateQueue={baseState:e.memoizedState,baseQueue:null,shared:{pending:null},effects:null}}function wn(e,t){e=e.updateQueue,t.updateQueue===e&&(t.updateQueue={baseState:e.baseState,baseQueue:e.baseQueue,shared:e.shared,effects:e.effects})}function kn(e,t){return(e={expirationTime:e,suspenseConfig:t,tag:0,payload:null,callback:null,next:null}).next=e}function Pn(e,t){if(null!==(e=e.updateQueue)){var n=(e=e.shared).pending;null===n?t.next=t:(t.next=n.next,n.next=t),e.pending=t}}function Rn(e,t){var n=e.alternate;null!==n&&wn(n,e),null===(n=(e=e.updateQueue).baseQueue)?(e.baseQueue=t.next=t,t.next=t):(t.next=n.next,n.next=t)}function _n(e,t,n,r){var i=e.updateQueue;En=!1;var l=i.baseQueue,a=i.shared.pending;if(null!==a){if(null!==l){var u=l.next;l.next=a.next,a.next=u}l=a,i.shared.pending=null,null!==(u=e.alternate)&&(null!==(u=u.updateQueue)&&(u.baseQueue=a))}if(null!==l){u=l.next;var s=i.baseState,c=0,f=null,d=null,p=null;if(null!==u)for(var h=u;;){if((a=h.expirationTime)c&&(c=a)}else{null!==p&&(p=p.next={expirationTime:1073741823,suspenseConfig:h.suspenseConfig,tag:h.tag,payload:h.payload,callback:h.callback,next:null}),wl(a,h.suspenseConfig);e:{var g=e,v=h;switch(a=t,m=n,v.tag){case 1:if("function"==typeof(g=v.payload)){s=g.call(m,s,a);break e}s=g;break e;case 3:g.effectTag=-4097&g.effectTag|64;case 0:if(null===(a="function"==typeof(g=v.payload)?g.call(m,s,a):g)||void 0===a)break e;s=o({},s,a);break e;case 2:En=!0}}null!==h.callback&&(e.effectTag|=32,null===(a=i.effects)?i.effects=[h]:a.push(h))}if(null===(h=h.next)||h===u){if(null===(a=i.shared.pending))break;h=l.next=a.next,a.next=u,i.baseQueue=l=a,i.shared.pending=null}}null===p?f=s:p.next=d,i.baseState=f,i.baseQueue=p,kl(c),e.expirationTime=c,e.memoizedState=s}}function Cn(e,t,n){if(e=t.effects,t.effects=null,null!==e)for(t=0;tm?(g=h,h=null):g=h.sibling;var v=d(i,h,o[m],u);if(null===v){null===h&&(h=g);break}e&&h&&null===v.alternate&&t(i,h),a=l(v,a,m),null===c?s=v:c.sibling=v,c=v,h=g}if(m===o.length)return n(i,h),s;if(null===h){for(;mm?(g=h,h=null):g=h.sibling;var y=d(i,h,v.value,u);if(null===y){null===h&&(h=g);break}e&&h&&null===y.alternate&&t(i,h),a=l(y,a,m),null===c?s=y:c.sibling=y,c=y,h=g}if(v.done)return n(i,h),s;if(null===h){for(;!v.done;m++,v=o.next())null!==(v=f(i,v.value,u))&&(a=l(v,a,m),null===c?s=v:c.sibling=v,c=v);return s}for(h=r(i,h);!v.done;m++,v=o.next())null!==(v=p(h,i,m,v.value,u))&&(e&&null!==v.alternate&&h.delete(null===v.key?m:v.key),a=l(v,a,m),null===c?s=v:c.sibling=v,c=v);return e&&h.forEach(function(e){return t(i,e)}),s}return function(e,r,l,o){var u="object"==typeof l&&null!==l&&l.type===Ie&&null===l.key;u&&(l=l.props.children);var s="object"==typeof l&&null!==l;if(s)switch(l.$$typeof){case Ne:e:{for(s=l.key,u=r;null!==u;){if(u.key===s){switch(u.tag){case 7:if(l.type===Ie){n(e,u.sibling),(r=i(u,l.props.children)).return=e,e=r;break e}break;default:if(u.elementType===l.type){n(e,u.sibling),(r=i(u,l.props)).ref=On(e,u,l),r.return=e,e=r;break e}}n(e,u);break}t(e,u),u=u.sibling}l.type===Ie?((r=$l(l.props.children,e.mode,o,l.key)).return=e,e=r):((o=Xl(l.type,l.key,l.props,null,e.mode,o)).ref=On(e,r,l),o.return=e,e=o)}return a(e);case ze:e:{for(u=l.key;null!==r;){if(r.key===u){if(4===r.tag&&r.stateNode.containerInfo===l.containerInfo&&r.stateNode.implementation===l.implementation){n(e,r.sibling),(r=i(r,l.children||[])).return=e,e=r;break e}n(e,r);break}t(e,r),r=r.sibling}(r=Gl(l,e.mode,o)).return=e,e=r}return a(e)}if("string"==typeof l||"number"==typeof l)return l=""+l,null!==r&&6===r.tag?(n(e,r.sibling),(r=i(r,l)).return=e,e=r):(n(e,r),(r=Kl(l,e.mode,o)).return=e,e=r),a(e);if(Qn(l))return h(e,r,l,o);if(Ve(l))return m(e,r,l,o);if(s&&jn(e,l),void 0===l&&!u)switch(e.tag){case 1:case 0:throw e=e.type,Error((e.displayName||e.name||"Component")+"(...): Nothing was returned from render. This usually means a return statement is missing. Or, to render nothing, return null.")}return n(e,r)}}var Wn=Hn(!0),Ln=Hn(!1),Bn={},Vn={current:Bn},Yn={current:Bn},qn={current:Bn};function Xn(e){if(e===Bn)throw Error("Expected host context to exist. This error is likely caused by a bug in React. Please file an issue.");return e}function $n(e,t){Et(qn,t),Et(Yn,e),Et(Vn,Bn),xt(Vn),Et(Vn,{isInAParentText:!1})}function Kn(){xt(Vn),xt(Yn),xt(qn)}function Gn(e){Xn(qn.current);var t=Xn(Vn.current),n=e.type;n="AndroidTextInput"===n||"RCTMultilineTextInputView"===n||"RCTSinglelineTextInputView"===n||"RCTText"===n||"RCTVirtualText"===n,t!==(n=t.isInAParentText!==n?{isInAParentText:n}:t)&&(Et(Yn,e),Et(Vn,n))}function Jn(e){Yn.current===e&&(xt(Vn),xt(Yn))}var Zn={current:0};function er(e){for(var t=e;null!==t;){if(13===t.tag){var n=t.memoizedState;if(null!==n&&(null===n.dehydrated||ct()||ct()))return t}else if(19===t.tag&&void 0!==t.memoizedProps.revealOrder){if(0!=(64&t.effectTag))return t}else if(null!==t.child){t.child.return=t,t=t.child;continue}if(t===e)break;for(;null===t.sibling;){if(null===t.return||t.return===e)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}function tr(e,t){return{responder:e,props:t}}var nr=_e.ReactCurrentDispatcher,rr=_e.ReactCurrentBatchConfig,ir=0,lr=null,ar=null,or=null,ur=!1;function sr(){throw Error("Invalid hook call. Hooks can only be called inside of the body of a function component. This could happen for one of the following reasons:\n1. You might have mismatching versions of React and the renderer (such as React DOM)\n2. You might be breaking the Rules of Hooks\n3. You might have more than one copy of React in the same app\nSee https://fb.me/react-invalid-hook-call for tips about how to debug and fix this problem.")}function cr(e,t){if(null===t)return!1;for(var n=0;nl))throw Error("Too many re-renders. React limits the number of renders to prevent an infinite loop.");l+=1,or=ar=null,t.updateQueue=null,nr.current=Fr,e=n(r,i)}while(t.expirationTime===ir)}if(nr.current=Ar,t=null!==ar&&null!==ar.next,ir=0,or=ar=lr=null,ur=!1,t)throw Error("Rendered fewer hooks than expected. This may be caused by an accidental early return statement.");return e}function dr(){var e={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return null===or?lr.memoizedState=or=e:or=or.next=e,or}function pr(){if(null===ar){var e=lr.alternate;e=null!==e?e.memoizedState:null}else e=ar.next;var t=null===or?lr.memoizedState:or.next;if(null!==t)or=t,ar=e;else{if(null===e)throw Error("Rendered more hooks than during the previous render.");e={memoizedState:(ar=e).memoizedState,baseState:ar.baseState,baseQueue:ar.baseQueue,queue:ar.queue,next:null},null===or?lr.memoizedState=or=e:or=or.next=e}return or}function hr(e,t){return"function"==typeof t?t(e):t}function mr(e){var t=pr(),n=t.queue;if(null===n)throw Error("Should have a queue. This is likely a bug in React. Please file an issue.");n.lastRenderedReducer=e;var r=ar,i=r.baseQueue,l=n.pending;if(null!==l){if(null!==i){var a=i.next;i.next=l.next,l.next=a}r.baseQueue=i=l,n.pending=null}if(null!==i){i=i.next,r=r.baseState;var o=a=l=null,u=i;do{var s=u.expirationTime;if(slr.expirationTime&&(lr.expirationTime=s,kl(s))}else null!==o&&(o=o.next={expirationTime:1073741823,suspenseConfig:u.suspenseConfig,action:u.action,eagerReducer:u.eagerReducer,eagerState:u.eagerState,next:null}),wl(s,u.suspenseConfig),r=u.eagerReducer===e?u.eagerState:e(r,u.action);u=u.next}while(null!==u&&u!==i);null===o?l=r:o.next=a,on(r,t.memoizedState)||(Or=!0),t.memoizedState=r,t.baseState=l,t.baseQueue=o,n.lastRenderedState=r}return[t.memoizedState,n.dispatch]}function gr(e){var t=pr(),n=t.queue;if(null===n)throw Error("Should have a queue. This is likely a bug in React. Please file an issue.");n.lastRenderedReducer=e;var r=n.dispatch,i=n.pending,l=t.memoizedState;if(null!==i){n.pending=null;var a=i=i.next;do{l=e(l,a.action),a=a.next}while(a!==i);on(l,t.memoizedState)||(Or=!0),t.memoizedState=l,null===t.baseQueue&&(t.baseState=l),n.lastRenderedState=l}return[l,r]}function vr(e){var t=dr();return"function"==typeof e&&(e=e()),t.memoizedState=t.baseState=e,e=(e=t.queue={pending:null,dispatch:null,lastRenderedReducer:hr,lastRenderedState:e}).dispatch=Ir.bind(null,lr,e),[t.memoizedState,e]}function yr(e,t,n,r){return e={tag:e,create:t,destroy:n,deps:r,next:null},null===(t=lr.updateQueue)?(t={lastEffect:null},lr.updateQueue=t,t.lastEffect=e.next=e):null===(n=t.lastEffect)?t.lastEffect=e.next=e:(r=n.next,n.next=e,e.next=r,t.lastEffect=e),e}function br(){return pr().memoizedState}function Tr(e,t,n,r){var i=dr();lr.effectTag|=e,i.memoizedState=yr(1|t,n,void 0,void 0===r?null:r)}function xr(e,t,n,r){var i=pr();r=void 0===r?null:r;var l=void 0;if(null!==ar){var a=ar.memoizedState;if(l=a.destroy,null!==r&&cr(r,a.deps))return void yr(t,n,l,r)}lr.effectTag|=e,i.memoizedState=yr(1|t,n,l,r)}function Er(e,t){return Tr(516,4,e,t)}function Sr(e,t){return xr(516,4,e,t)}function wr(e,t){return xr(4,2,e,t)}function kr(e,t){return"function"==typeof t?(e=e(),t(e),function(){t(null)}):null!==t&&void 0!==t?(e=e(),t.current=e,function(){t.current=null}):void 0}function Pr(e,t,n){return n=null!==n&&void 0!==n?n.concat([e]):null,xr(4,2,kr.bind(null,t,e),n)}function Rr(){}function _r(e,t){return dr().memoizedState=[e,void 0===t?null:t],e}function Cr(e,t){var n=pr();t=void 0===t?null:t;var r=n.memoizedState;return null!==r&&null!==t&&cr(t,r[1])?r[0]:(n.memoizedState=[e,t],e)}function Nr(e,t){var n=pr();t=void 0===t?null:t;var r=n.memoizedState;return null!==r&&null!==t&&cr(t,r[1])?r[0]:(e=e(),n.memoizedState=[e,t],e)}function zr(e,t,n){var r=Zt();tn(98>r?98:r,function(){e(!0)}),tn(97 component.");i=ht(),u.UIManager.createView(i,"RCTRawText",e,{text:r}),ye.set(i,t),t.stateNode=i}return null;case 13:return xt(Zn),r=t.memoizedState,0!=(64&t.effectTag)?(t.expirationTime=n,t):(r=null!==r,i=!1,null!==e&&(i=null!==(n=e.memoizedState),r||null===n||null!==(n=e.child.sibling)&&(null!==(l=t.firstEffect)?(t.firstEffect=n,n.nextEffect=l):(t.firstEffect=t.lastEffect=n,n.nextEffect=null),n.effectTag=8)),r&&!i&&0!=(2&t.mode)&&(null===e&&!0!==t.memoizedProps.unstable_avoidThisFallback||0!=(1&Zn.current)?qi===Fi&&(qi=ji):(qi!==Fi&&qi!==ji||(qi=Hi),0!==Ji&&null!==Bi&&(ea(Bi,Yi),ta(Bi,Ji)))),(r||i)&&(t.effectTag|=4),null);case 4:return Kn(),Kr(t),null;case 10:return yn(t),null;case 17:return _t(t.type)&&Ct(),null;case 19:if(xt(Zn),null===(r=t.memoizedState))return null;if(i=0!=(64&t.effectTag),null===(l=r.rendering)){if(i)li(r,!1);else if(qi!==Fi||null!==e&&0!=(64&e.effectTag))for(e=t.child;null!==e;){if(null!==(l=er(e))){for(t.effectTag|=64,li(r,!1),null!==(e=l.updateQueue)&&(t.updateQueue=e,t.effectTag|=4),null===r.lastEffect&&(t.firstEffect=null),t.lastEffect=r.lastEffect,e=n,r=t.child;null!==r;)n=e,(i=r).effectTag&=2,i.nextEffect=null,i.firstEffect=null,i.lastEffect=null,null===(l=i.alternate)?(i.childExpirationTime=0,i.expirationTime=n,i.child=null,i.memoizedProps=null,i.memoizedState=null,i.updateQueue=null,i.dependencies=null):(i.childExpirationTime=l.childExpirationTime,i.expirationTime=l.expirationTime,i.child=l.child,i.memoizedProps=l.memoizedProps,i.memoizedState=l.memoizedState,i.updateQueue=l.updateQueue,n=l.dependencies,i.dependencies=null===n?null:{expirationTime:n.expirationTime,firstContext:n.firstContext,responders:n.responders}),r=r.sibling;return Et(Zn,1&Zn.current|2),t.child}e=e.sibling}}else{if(!i)if(null!==(e=er(l))){if(t.effectTag|=64,i=!0,null!==(e=e.updateQueue)&&(t.updateQueue=e,t.effectTag|=4),li(r,!0),null===r.tail&&"hidden"===r.tailMode&&!l.alternate)return null!==(t=t.lastEffect=r.lastEffect)&&(t.nextEffect=null),null}else 2*Jt()-r.renderingStartTime>r.tailExpiration&&1t)&&sl.set(e,t))}}function gl(e,t){e.expirationTime=(e=n>(e=e.nextKnownPendingLevel)?n:e)&&t!==e?0:e}function yl(e){if(0!==e.lastExpiredTime)e.callbackExpirationTime=1073741823,e.callbackPriority=99,e.callbackNode=rn(Tl.bind(null,e));else{var t=vl(e),n=e.callbackNode;if(0===t)null!==n&&(e.callbackNode=null,e.callbackExpirationTime=0,e.callbackPriority=90);else{var r=pl();if(1073741823===t?r=99:1===t||2===t?r=95:r=0>=(r=10*(1073741821-t)-10*(1073741821-r))?99:250>=r?98:5250>=r?97:95,null!==n){var i=e.callbackPriority;if(e.callbackExpirationTime===t&&i>=r)return;n!==Vt&&Dt(n)}e.callbackExpirationTime=t,e.callbackPriority=r,t=1073741823===t?rn(Tl.bind(null,e)):nn(r,bl.bind(null,e),{timeout:10*(1073741821-t)-Jt()}),e.callbackNode=t}}}function bl(e,t){if(dl=0,t){t=pl();var n=e.lastExpiredTime;return(0===n||n>t)&&(e.lastExpiredTime=t),yl(e),null}if(0===(n=vl(e)))return null;if(t=e.callbackNode,(48&Li)!==Mi)throw Error("Should not already be working.");Ul();var r=n,i=Li;Li|=Ui;var l=Sl();for(e===Bi&&r===Yi||xl(e,r);;)try{_l();break}catch(t){El(e,t)}if(vn(),zi.current=l,Li=i,null!==Vi?i=Fi:(Bi=null,i=qi),i!==Fi){if(i===Oi&&(i=Pl(e,n=2=n)){e.lastPingedTime=n,xl(e,n);break}if(0!==(l=vl(e))&&l!==n)break;if(0!==i&&i!==n){e.lastPingedTime=i;break}e.timeoutHandle=vt(Il.bind(null,e),r);break}Il(e);break;case Hi:if(ea(e,n),n===(i=e.lastSuspendedTime)&&(e.nextKnownPendingLevel=zl(r)),Zi&&(0===(r=e.lastPingedTime)||r>=n)){e.lastPingedTime=n,xl(e,n);break}if(0!==(r=vl(e))&&r!==n)break;if(0!==i&&i!==n){e.lastPingedTime=i;break}if(1073741823!==Ki?r=10*(1073741821-Ki)-Jt():1073741823===$i?r=0:(r=10*(1073741821-$i)-5e3,n=10*(1073741821-n)-(i=Jt()),0>(r=i-r)&&(r=0),n<(r=(120>r?120:480>r?480:1080>r?1080:1920>r?1920:3e3>r?3e3:4320>r?4320:1960*Ni(r/1960))-r)&&(r=n)),10=(r=0|a.busyMinDurationMs)?r=0:(i=0|a.busyDelayMs,r=(l=Jt()-(10*(1073741821-l)-(0|a.timeoutMs||5e3)))<=i?0:i+r-l),10=t?Yi:t:1073741823);if(0!==e.tag&&n===Oi&&(n=Pl(e,t=2 component higher in the tree to provide a loading indicator or placeholder to display."+fn(a))}qi!==Wi&&(qi=Oi),o=ui(o,a),f=l;do{switch(f.tag){case 3:u=o,f.effectTag|=4096,f.expirationTime=t,Rn(f,Ri(f,u,t));break e;case 1:u=o;var T=f.type,x=f.stateNode;if(0==(64&f.effectTag)&&("function"==typeof T.getDerivedStateFromError||null!==x&&"function"==typeof x.componentDidCatch&&(null===ll||!ll.has(x)))){f.effectTag|=4096,f.expirationTime=t,Rn(f,_i(f,u,t));break e}}f=f.return}while(null!==f)}Vi=Nl(Vi)}catch(e){t=e;continue}break}}function Sl(){var e=zi.current;return zi.current=Ar,null===e?Ar:e}function wl(e,t){e<$i&&2Ji&&(Ji=e)}function Pl(e,t){var n=Li;Li|=Ui;var r=Sl();for(e===Bi&&t===Yi||xl(e,t);;)try{Rl();break}catch(t){El(e,t)}if(vn(),Li=n,zi.current=r,null!==Vi)throw Error("Cannot commit an incomplete root. This error is likely caused by a bug in React. Please file an issue.");return Bi=null,qi}function Rl(){for(;null!==Vi;)Vi=Cl(Vi)}function _l(){for(;null!==Vi&&!Yt();)Vi=Cl(Vi)}function Cl(e){var t=Ci(e.alternate,e,Yi);return e.memoizedProps=e.pendingProps,null===t&&(t=Nl(e)),Ii.current=null,t}function Nl(e){Vi=e;do{var t=Vi.alternate;if(e=Vi.return,0==(2048&Vi.effectTag)){if(t=ai(t,Vi,Yi),1===Yi||1!==Vi.childExpirationTime){for(var n=0,r=Vi.child;null!==r;){var i=r.expirationTime,l=r.childExpirationTime;i>n&&(n=i),l>n&&(n=l),r=r.sibling}Vi.childExpirationTime=n}if(null!==t)return t;null!==e&&0==(2048&e.effectTag)&&(null===e.firstEffect&&(e.firstEffect=Vi.firstEffect),null!==Vi.lastEffect&&(null!==e.lastEffect&&(e.lastEffect.nextEffect=Vi.firstEffect),e.lastEffect=Vi.lastEffect),1(e=e.childExpirationTime)?t:e}function Il(e){var t=Zt();return tn(99,Ml.bind(null,e,t)),null}function Ml(e,t){do{Ul()}while(null!==ol);if((48&Li)!==Mi)throw Error("Should not already be working.");var n=e.finishedWork,r=e.finishedExpirationTime;if(null===n)return null;if(e.finishedWork=null,e.finishedExpirationTime=0,n===e.current)throw Error("Cannot commit the same tree as before. This error is likely caused by a bug in React. Please file an issue.");e.callbackNode=null,e.callbackExpirationTime=0,e.callbackPriority=90,e.nextKnownPendingLevel=0;var i=zl(n);if(e.firstPendingTime=i,r<=e.lastSuspendedTime?e.firstSuspendedTime=e.lastSuspendedTime=e.nextKnownPendingLevel=0:r<=e.firstSuspendedTime&&(e.firstSuspendedTime=r-1),r<=e.lastPingedTime&&(e.lastPingedTime=0),r<=e.lastExpiredTime&&(e.lastExpiredTime=0),e===Bi&&(Vi=Bi=null,Yi=0),1=n?ei(e,t,n):(Et(Zn,1&Zn.current),null!==(t=ii(e,t,n))?t.sibling:null);Et(Zn,1&Zn.current);break;case 19:if(r=t.childExpirationTime>=n,0!=(64&e.effectTag)){if(r)return ri(e,t,n);t.effectTag|=64}if(null!==(i=t.memoizedState)&&(i.rendering=null,i.tail=null),Et(Zn,Zn.current),!r)return null}return ii(e,t,n)}Or=!1}else Or=!1;switch(t.expirationTime=0,t.tag){case 2:if(r=t.type,null!==e&&(e.alternate=null,t.alternate=null,t.effectTag|=2),e=t.pendingProps,i=Rt(t,wt.current),Tn(t,n),i=fr(null,t,r,e,i,n),t.effectTag|=1,"object"==typeof i&&null!==i&&"function"==typeof i.render&&void 0===i.$$typeof){if(t.tag=1,t.memoizedState=null,t.updateQueue=null,_t(r)){var l=!0;It(t)}else l=!1;t.memoizedState=null!==i.state&&void 0!==i.state?i.state:null,Sn(t);var a=r.getDerivedStateFromProps;"function"==typeof a&&In(t,r,a,e),i.updater=Mn,t.stateNode=i,i._reactInternalFiber=t,Fn(t,r,e,n),t=qr(null,t,r,!0,l,n)}else t.tag=0,jr(null,t,i,n),t=t.child;return t;case 16:e:{if(i=t.elementType,null!==e&&(e.alternate=null,t.alternate=null,t.effectTag|=2),e=t.pendingProps,Ye(i),1!==i._status)throw i._result;switch(i=i._result,t.type=i,l=t.tag=Yl(i),e=dn(i,e),l){case 0:t=Vr(null,t,i,e,n);break e;case 1:t=Yr(null,t,i,e,n);break e;case 11:t=Hr(null,t,i,e,n);break e;case 14:t=Wr(null,t,i,dn(i.type,e),r,n);break e}throw Error("Element type is invalid. Received a promise that resolves to: "+i+". Lazy element type must resolve to a class or function.")}return t;case 0:return r=t.type,i=t.pendingProps,Vr(e,t,r,i=t.elementType===r?i:dn(r,i),n);case 1:return r=t.type,i=t.pendingProps,Yr(e,t,r,i=t.elementType===r?i:dn(r,i),n);case 3:if(Xr(t),r=t.updateQueue,null===e||null===r)throw Error("If the root does not have an updateQueue, we should have already bailed out. This error is likely caused by a bug in React. Please file an issue.");return r=t.pendingProps,i=null!==(i=t.memoizedState)?i.element:null,wn(e,t),_n(t,r,null,n),(r=t.memoizedState.element)===i?t=ii(e,t,n):(jr(e,t,r,n),t=t.child),t;case 5:return Gn(t),r=t.pendingProps.children,Br(e,t),jr(e,t,r,n),t=t.child;case 6:return null;case 13:return ei(e,t,n);case 4:return $n(t,t.stateNode.containerInfo),r=t.pendingProps,null===e?t.child=Wn(t,null,r,n):jr(e,t,r,n),t.child;case 11:return r=t.type,i=t.pendingProps,Hr(e,t,r,i=t.elementType===r?i:dn(r,i),n);case 7:return jr(e,t,t.pendingProps,n),t.child;case 8:case 12:return jr(e,t,t.pendingProps.children,n),t.child;case 10:e:{r=t.type._context,i=t.pendingProps,a=t.memoizedProps,l=i.value;var o=t.type._context;if(Et(pn,o._currentValue),o._currentValue=l,null!==a)if(o=a.value,0===(l=on(o,l)?0:0|("function"==typeof r._calculateChangedBits?r._calculateChangedBits(o,l):1073741823))){if(a.children===i.children&&!kt.current){t=ii(e,t,n);break e}}else for(null!==(o=t.child)&&(o.return=t);null!==o;){var u=o.dependencies;if(null!==u){a=o.child;for(var s=u.firstContext;null!==s;){if(s.context===r&&0!=(s.observedBits&l)){1===o.tag&&((s=kn(n,null)).tag=2,Pn(o,s)),o.expirationTime=t&&e<=t}function ea(e,t){var n=e.firstSuspendedTime,r=e.lastSuspendedTime;nt||0===n)&&(e.lastSuspendedTime=t),t<=e.lastPingedTime&&(e.lastPingedTime=0),t<=e.lastExpiredTime&&(e.lastExpiredTime=0)}function ta(e,t){t>e.firstPendingTime&&(e.firstPendingTime=t);var n=e.firstSuspendedTime;0!==n&&(t>=n?e.firstSuspendedTime=e.lastSuspendedTime=e.nextKnownPendingLevel=0:t>=e.lastSuspendedTime&&(e.lastSuspendedTime=t+1),t>e.nextKnownPendingLevel&&(e.nextKnownPendingLevel=t))}function na(e){var t=e._reactInternalFiber;if(void 0===t){if("function"==typeof e.render)throw Error("Unable to find node on an unmounted component.");throw Error("Argument appears to not be a ReactComponent. Keys: "+Object.keys(e))}return null===(e=Ge(t))?null:e.stateNode}function ra(e,t,n,r){var i=t.current,l=pl(),a=Nn.suspense;l=hl(l,i,a);e:if(n){n=n._reactInternalFiber;t:{if(Xe(n)!==n||1!==n.tag)throw Error("Expected subtree parent to be a mounted class component. This error is likely caused by a bug in React. Please file an issue.");var o=n;do{switch(o.tag){case 3:o=o.stateNode.context;break t;case 1:if(_t(o.type)){o=o.stateNode.__reactInternalMemoizedMergedChildContext;break t}}o=o.return}while(null!==o);throw Error("Found unexpected detached subtree parent. This error is likely caused by a bug in React. Please file an issue.")}if(1===n.tag){var u=n.type;if(_t(u)){n=zt(n,u,o);break e}}n=o}else n=St;return null===t.context?t.context=n:t.pendingContext=n,(t=kn(l,a)).payload={element:e},null!==(r=void 0===r?null:r)&&(t.callback=r),Pn(i,t),ml(i,l),l}function ia(e,t,n){var r=30&&(I=new Set,j(-1))},e.setSelectedLog=j,e.clearWarnings=function(){var t=Array.from(I).filter(function(t){return'warn'!==t.level});t.length!==I.size&&(I=new Set(t),j(-1),B())},e.clearErrors=function(){var t=Array.from(I).filter(function(t){return'error'!==t.level&&'fatal'!==t.level});t.length!==I.size&&(I=new Set(t),j(-1))},e.dismiss=F,e.setWarningFilter=function(t){R=t},e.setAppInfo=function(t){L=t},e.getAppInfo=function(){return null!=L?L():null},e.checkWarningFilter=function(t){return R(t)},e.addIgnorePatterns=function(t){var n=t.filter(function(t){if(t instanceof RegExp){for(var n,o=S(A.entries());!(n=o()).done;){var u=n.value;if(u instanceof RegExp&&u.toString()===t.toString())return!1}return!0}return!A.has(t)});if(0===n.length)return;for(var o,u=S(n);!(o=u()).done;){var l=o.value;A.add(l),I=new Set(Array.from(I).filter(function(t){return!N(t.message.content)}))}B()},e.setDisabled=function(t){if(t===k)return;k=t,B()},e.isDisabled=function(){return k},e.observe=T,e.withSubscription=function(t){return(function(n){(0,l.default)(h,n);var v,y,p=(v=h,y=b(),function(){var t,n=(0,c.default)(v);if(y){var o=(0,c.default)(this).constructor;t=Reflect.construct(n,arguments,o)}else t=n.apply(this,arguments);return(0,s.default)(this,t)});function h(){var t;(0,o.default)(this,h);for(var n=arguments.length,u=new Array(n),l=0;l=l.length-1&&j(o-1),F(l[o]))},t._handleMinimize=function(){j(-1)},t._handleSetSelectedLog=function(t){j(t)},t}return(0,u.default)(h,[{key:"componentDidCatch",value:function(t,n){M(t,n.componentStack)}},{key:"render",value:function(){return this.state.hasError?null:f.createElement(t,{logs:Array.from(this.state.logs),isDisabled:this.state.isDisabled,selectedLogIndex:this.state.selectedLogIndex})}},{key:"componentDidMount",value:function(){var t=this;this._subscription=T(function(n){t.setState(n)})}},{key:"componentWillUnmount",value:function(){null!=this._subscription&&this._subscription.unsubscribe()}}],[{key:"getDerivedStateFromError",value:function(){return{hasError:!0}}}]),h})(f.Component)};var o=n(r(d[2])),u=n(r(d[3])),l=n(r(d[4])),s=n(r(d[5])),c=n(r(d[6])),f=t(r(d[7])),v=n(r(d[8])),y=r(d[9]),p=n(r(d[10])),h=n(r(d[11]));function b(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(t){return!1}}function S(t,n){var o;if("undefined"==typeof Symbol||null==t[Symbol.iterator]){if(Array.isArray(t)||(o=w(t))||n&&t&&"number"==typeof t.length){o&&(t=o);var u=0;return function(){return u>=t.length?{done:!0}:{done:!1,value:t[u++]}}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}return(o=t[Symbol.iterator]()).next.bind(o)}function w(t,n){if(t){if("string"==typeof t)return E(t,n);var o=Object.prototype.toString.call(t).slice(8,-1);return"Object"===o&&t.constructor&&(o=t.constructor.name),"Map"===o||"Set"===o?Array.from(t):"Arguments"===o||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(o)?E(t,n):void 0}}function E(t,n){(null==n||n>t.length)&&(n=t.length);for(var o=0,u=new Array(n);o=0;){if('syntax'===u[l].level){o=l;break}l-=1}_=o,B(),h.default&&setTimeout(function(){n<0&&o>=0?h.default.show():n>=0&&o<0&&h.default.hide()},0)}function F(t){I.has(t)&&(I.delete(t),B())}function T(t){var n={observer:t};return x.add(n),t(C()),{unsubscribe:function(){x.delete(n)}}}},101,[10,8,27,28,38,40,37,57,102,111,113,116,96]);
-__d(function(g,r,i,a,m,e,d){'use strict';var t=r(d[0]),s=r(d[1]);Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0;var l=s(r(d[2])),u=s(r(d[3])),n=t(r(d[4])),c=(function(){function t(s){(0,l.default)(this,t),this.symbolicated={error:null,stack:null,status:'NONE'},this.level=s.level,this.type=s.type,this.message=s.message,this.stack=s.stack,this.category=s.category,this.componentStack=s.componentStack,this.codeFrame=s.codeFrame,this.isComponentError=s.isComponentError,this.count=1}return(0,u.default)(t,[{key:"incrementCount",value:function(){this.count+=1}},{key:"getAvailableStack",value:function(){return'COMPLETE'===this.symbolicated.status?this.symbolicated.stack:this.stack}},{key:"retrySymbolicate",value:function(t){'COMPLETE'!==this.symbolicated.status&&(n.deleteStack(this.stack),this.handleSymbolicate(t))}},{key:"symbolicate",value:function(t){'NONE'===this.symbolicated.status&&this.handleSymbolicate(t)}},{key:"handleSymbolicate",value:function(t){var s=this;'PENDING'!==this.symbolicated.status&&(this.updateStatus(null,null,null,t),n.symbolicate(this.stack).then(function(l){s.updateStatus(null,null==l?void 0:l.stack,null==l?void 0:l.codeFrame,t)},function(l){s.updateStatus(l,null,null,t)}))}},{key:"updateStatus",value:function(t,s,l,u){var n=this.symbolicated.status;null!=t?this.symbolicated={error:t,stack:null,status:'FAILED'}:null!=s?(l&&(this.codeFrame=l),this.symbolicated={error:null,stack:s,status:'COMPLETE'}):this.symbolicated={error:null,stack:null,status:'PENDING'},u&&n!==this.symbolicated.status&&u(this.symbolicated.status)}}]),t})();e.default=c},102,[10,8,27,28,103]);
-__d(function(g,r,i,a,m,e,d){'use strict';var t=r(d[0]);Object.defineProperty(e,"__esModule",{value:!0}),e.deleteStack=function(t){u.delete(t)},e.symbolicate=function(t){var o=u.get(t);null==o&&(o=(0,n.default)(t).then(f),u.set(t,o));return o};var n=t(r(d[1]));function o(t,n){var o;if("undefined"==typeof Symbol||null==t[Symbol.iterator]){if(Array.isArray(t)||(o=l(t))||n&&t&&"number"==typeof t.length){o&&(t=o);var c=0;return function(){return c>=t.length?{done:!0}:{done:!1,value:t[c++]}}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}return(o=t[Symbol.iterator]()).next.bind(o)}function l(t,n){if(t){if("string"==typeof t)return c(t,n);var o=Object.prototype.toString.call(t).slice(8,-1);return"Object"===o&&t.constructor&&(o=t.constructor.name),"Map"===o||"Set"===o?Array.from(t):"Arguments"===o||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(o)?c(t,n):void 0}}function c(t,n){(null==n||n>t.length)&&(n=t.length);for(var o=0,l=new Array(n);o=0;--h){var f=this.tryEntries[h],l=f.completion;if("root"===f.tryLoc)return u("end");if(f.tryLoc<=this.prev){var s=c.call(f,"catchLoc"),p=c.call(f,"finallyLoc");if(s&&p){if(this.prev=0;--o){var u=this.tryEntries[o];if(u.tryLoc<=this.prev&&c.call(u,"finallyLoc")&&this.prev=0;--n){var o=this.tryEntries[n];if(o.finallyLoc===t)return this.complete(o.completion,o.afterLoc),A(o),b}},catch:function(t){for(var n=this.tryEntries.length-1;n>=0;--n){var o=this.tryEntries[n];if(o.tryLoc===t){var c=o.completion;if("throw"===c.type){var u=c.arg;A(o)}return u}}throw new Error("illegal catch attempt")},delegateYield:function(t,o,c){return this.delegate={iterator:Y(t),resultName:o,nextLoc:c},"next"===this.method&&(this.arg=n),b}},t})("object"==typeof m?m.exports:{});try{regeneratorRuntime=t}catch(n){Function("r","regeneratorRuntime = r")(t)}},106,[]);
-__d(function(g,r,i,a,m,e,d){'use strict';var t=r(d[0]);Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0;var o=t(r(d[1])).getEnforcing('SourceCode');e.default=o},107,[10,12]);
-__d(function(g,r,i,a,m,e,d){'use strict';var t,n=r(d[0])(r(d[1])),l='http://localhost:8081/';m.exports=function(){if(void 0===t){var o=n.default.getConstants().scriptURL.match(/^https?:\/\/.*?\//);t=o?o[0]:null}return{url:t||l,bundleLoadedFromServer:null!==t}}},108,[8,107]);
-__d(function(g,r,i,a,m,e,d){'use strict';r(d[0]),m.exports={fetch:fetch,Headers:Headers,Request:Request,Response:Response}},109,[110]);
-__d(function(g,r,i,a,m,e,d){var t,o;t=this,o=function(t){'use strict';var o='undefined'!=typeof globalThis&&globalThis||'undefined'!=typeof self&&self||void 0!==o&&o,n={searchParams:'URLSearchParams'in o,iterable:'Symbol'in o&&'iterator'in Symbol,blob:'FileReader'in o&&'Blob'in o&&(function(){try{return new Blob,!0}catch(t){return!1}})(),formData:'FormData'in o,arrayBuffer:'ArrayBuffer'in o};if(n.arrayBuffer)var s=['[object Int8Array]','[object Uint8Array]','[object Uint8ClampedArray]','[object Int16Array]','[object Uint16Array]','[object Int32Array]','[object Uint32Array]','[object Float32Array]','[object Float64Array]'],h=ArrayBuffer.isView||function(t){return t&&s.indexOf(Object.prototype.toString.call(t))>-1};function f(t){if('string'!=typeof t&&(t=String(t)),/[^a-z0-9\-#$%&'*+.^_`|~!]/i.test(t)||''===t)throw new TypeError('Invalid character in header field name');return t.toLowerCase()}function u(t){return'string'!=typeof t&&(t=String(t)),t}function c(t){var o={next:function(){var o=t.shift();return{done:void 0===o,value:o}}};return n.iterable&&(o[Symbol.iterator]=function(){return o}),o}function y(t){this.map={},t instanceof y?t.forEach(function(t,o){this.append(o,t)},this):Array.isArray(t)?t.forEach(function(t){this.append(t[0],t[1])},this):t&&Object.getOwnPropertyNames(t).forEach(function(o){this.append(o,t[o])},this)}function l(t){if(t.bodyUsed)return Promise.reject(new TypeError('Already read'));t.bodyUsed=!0}function p(t){return new Promise(function(o,n){t.onload=function(){o(t.result)},t.onerror=function(){n(t.error)}})}function b(t){var o=new FileReader,n=p(o);return o.readAsArrayBuffer(t),n}function w(t){for(var o=new Uint8Array(t),n=new Array(o.length),s=0;s-1?s:n),this.mode=o.mode||this.mode||null,this.signal=o.signal||this.signal,this.referrer=null,('GET'===this.method||'HEAD'===this.method)&&h)throw new TypeError('Body not allowed for GET or HEAD requests');if(this._initBody(h),!('GET'!==this.method&&'HEAD'!==this.method||'no-store'!==o.cache&&'no-cache'!==o.cache)){var f=/([?&])_=[^&]*/;if(f.test(this.url))this.url=this.url.replace(f,'$1_='+(new Date).getTime());else{this.url+=(/\?/.test(this.url)?'&':'?')+'_='+(new Date).getTime()}}}function A(t){var o=new FormData;return t.trim().split('&').forEach(function(t){if(t){var n=t.split('='),s=n.shift().replace(/\+/g,' '),h=n.join('=').replace(/\+/g,' ');o.append(decodeURIComponent(s),decodeURIComponent(h))}}),o}function B(t,o){if(!(this instanceof B))throw new TypeError('Please use the "new" operator, this DOM object constructor cannot be called as a function.');o||(o={}),this.type='default',this.status=void 0===o.status?200:o.status,this.ok=this.status>=200&&this.status<300,this.statusText='statusText'in o?o.statusText:'',this.headers=new y(o.headers),this.url=o.url||'',this._initBody(t)}T.prototype.clone=function(){return new T(this,{body:this._bodyInit})},_.call(T.prototype),_.call(B.prototype),B.prototype.clone=function(){return new B(this._bodyInit,{status:this.status,statusText:this.statusText,headers:new y(this.headers),url:this.url})},B.error=function(){var t=new B(null,{status:0,statusText:''});return t.type='error',t};var x=[301,302,303,307,308];B.redirect=function(t,o){if(-1===x.indexOf(o))throw new RangeError('Invalid status code');return new B(null,{status:o,headers:{location:t}})},t.DOMException=o.DOMException;try{new t.DOMException}catch(o){t.DOMException=function(t,o){this.message=t,this.name=o;var n=Error(t);this.stack=n.stack},t.DOMException.prototype=Object.create(Error.prototype),t.DOMException.prototype.constructor=t.DOMException}function O(s,h){return new Promise(function(f,c){var l=new T(s,h);if(l.signal&&l.signal.aborted)return c(new t.DOMException('Aborted','AbortError'));var p=new XMLHttpRequest;function b(){p.abort()}p.onload=function(){var t,o,n={status:p.status,statusText:p.statusText,headers:(t=p.getAllResponseHeaders()||'',o=new y,t.replace(/\r?\n[\t ]+/g,' ').split('\r').map(function(t){return 0===t.indexOf('\n')?t.substr(1,t.length):t}).forEach(function(t){var n=t.split(':'),s=n.shift().trim();if(s){var h=n.join(':').trim();o.append(s,h)}}),o)};n.url='responseURL'in p?p.responseURL:n.headers.get('X-Request-URL');var s='response'in p?p.response:p.responseText;setTimeout(function(){f(new B(s,n))},0)},p.onerror=function(){setTimeout(function(){c(new TypeError('Network request failed'))},0)},p.ontimeout=function(){setTimeout(function(){c(new TypeError('Network request failed'))},0)},p.onabort=function(){setTimeout(function(){c(new t.DOMException('Aborted','AbortError'))},0)},p.open(l.method,(function(t){try{return''===t&&o.location.href?o.location.href:t}catch(o){return t}})(l.url),!0),'include'===l.credentials?p.withCredentials=!0:'omit'===l.credentials&&(p.withCredentials=!1),'responseType'in p&&(n.blob?p.responseType='blob':n.arrayBuffer&&l.headers.get('Content-Type')&&-1!==l.headers.get('Content-Type').indexOf('application/octet-stream')&&(p.responseType='arraybuffer')),!h||'object'!=typeof h.headers||h.headers instanceof y?l.headers.forEach(function(t,o){p.setRequestHeader(o,t)}):Object.getOwnPropertyNames(h.headers).forEach(function(t){p.setRequestHeader(t,u(h.headers[t]))}),l.signal&&(l.signal.addEventListener('abort',b),p.onreadystatechange=function(){4===p.readyState&&l.signal.removeEventListener('abort',b)}),p.send(void 0===l._bodyInit?null:l._bodyInit)})}O.polyfill=!0,o.fetch||(o.fetch=O,o.Headers=y,o.Request=T,o.Response=B),t.Headers=y,t.Request=T,t.Response=B,t.fetch=O,Object.defineProperty(t,'__esModule',{value:!0})},'object'==typeof e&&void 0!==m?o(e):'function'==typeof define&&define.amd?define(['exports'],o):o(t.WHATWGFetch={})},110,[]);
-__d(function(g,r,i,a,m,e,d){'use strict';var t=r(d[0]);Object.defineProperty(e,"__esModule",{value:!0}),e.parseInterpolation=B,e.parseComponentStack=h,e.parseLogBoxException=function(t){var u=null!=t.originalMessage?t.originalMessage:'Unknown',o=u.match(C);if(o){var F=o.slice(1),s=(0,n.default)(F,5),D=s[0],l=s[1],f=s[2],p=s[3],E=s[4];return{level:'fatal',type:'Metro Error',stack:[],isComponentError:!1,componentStack:[],codeFrame:{fileName:l,location:{row:parseInt(f,10),column:parseInt(p,10)},content:E},message:{content:D,substitutions:[]},category:l+"-"+f+"-"+p}}var k=u.match(y);if(k){var x=k.slice(1),O=(0,n.default)(x,5),S=O[0],j=O[1],w=O[2],A=O[3],I=O[4];return{level:'syntax',stack:[],isComponentError:!1,componentStack:[],codeFrame:{fileName:S,location:{row:parseInt(w,10),column:parseInt(A,10)},content:I},message:{content:j,substitutions:[]},category:S+"-"+w+"-"+A}}var P=u.match(v);if(P){var M=P.slice(1),N=(0,n.default)(M,3),T=N[0],_=N[1],L=N[2];return{level:'syntax',stack:[],isComponentError:!1,componentStack:[],codeFrame:{fileName:T,location:null,content:L},message:{content:_,substitutions:[]},category:T+"-1-1"}}if(u.match(/^TransformError /))return{level:'syntax',stack:t.stack,isComponentError:t.isComponentError,componentStack:[],message:{content:u,substitutions:[]},category:u};var U=t.componentStack;if(t.isFatal||t.isComponentError)return c({level:'fatal',stack:t.stack,isComponentError:t.isComponentError,componentStack:null!=U?h(U):[]},B([u]));if(null!=U)return c({level:'error',stack:t.stack,isComponentError:t.isComponentError,componentStack:h(U)},B([u]));return c({level:'error',stack:t.stack,isComponentError:t.isComponentError},b([u]))},e.parseLogBoxLog=b;var u=t(r(d[1])),n=t(r(d[2])),o=t(r(d[3])),F=t(r(d[4])),s=t(r(d[5]));function D(t,u){var n=Object.keys(t);if(Object.getOwnPropertySymbols){var o=Object.getOwnPropertySymbols(t);u&&(o=o.filter(function(u){return Object.getOwnPropertyDescriptor(t,u).enumerable})),n.push.apply(n,o)}return n}function c(t){for(var n=1;n=t.length?{done:!0}:{done:!1,value:t[o++]}}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}return(n=t[Symbol.iterator]()).next.bind(n)}function f(t,u){if(t){if("string"==typeof t)return p(t,u);var n=Object.prototype.toString.call(t).slice(8,-1);return"Object"===n&&t.constructor&&(n=t.constructor.name),"Map"===n||"Set"===n?Array.from(t):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?p(t,u):void 0}}function p(t,u){(null==u||u>t.length)&&(u=t.length);for(var n=0,o=new Array(u);n]{2}[\t-\r 0-9\xA0\u1680\u2000-\u200A\u2028\u2029\u202F\u205F\u3000\uFEFF]+ \|(?:[\0-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+|\x1B(?:[\0-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+)/,C=/^(?:InternalError Metro has encountered an error:) ((?:[\0-\t\x0B\f\x0E-\u2027\u202A-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])*): ((?:[\0-\t\x0B\f\x0E-\u2027\u202A-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])*) \(([0-9]+):([0-9]+)\)\n\n((?:[\0-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])+)/,E=F.default.BOM+'%s';function B(t){var u=[],n=[],F=[],D=(0,o.default)(t);if('string'==typeof D[0]){for(var c,f=String(D.shift()).split('%s'),p=f.length-1,y=D.splice(0,p),v='',C='',B=0,h=l(f);!(c=h()).done;){var b=c.value;if(v+=b,C+=b,B
diff --git a/android/app/build.gradle b/android/app/build.gradle
index cb31af8..36af627 100644
--- a/android/app/build.gradle
+++ b/android/app/build.gradle
@@ -1,6 +1,7 @@
apply plugin: "com.android.application"
import com.android.build.OutputFile
+import org.apache.tools.ant.taskdefs.condition.Os
/**
* The react.gradle file registers a task for each build variant (e.g. bundleDebugJsAndAssets
@@ -114,33 +115,112 @@ def jscFlavor = 'org.webkit:android-jsc:+'
/**
* Whether to enable the Hermes VM.
*
* This should be set on project.ext.react and mirrored here. If it is not set
* on project.ext.react, JavaScript will not be compiled to Hermes Bytecode
* and the benefits of using Hermes will therefore be sharply reduced.
*/
def enableHermes = project.ext.react.get("enableHermes", false);
+/**
+ * Architectures to build native code for.
+ */
+def reactNativeArchitectures() {
+ def value = project.getProperties().get("reactNativeArchitectures")
+ return value ? value.split(",") : ["armeabi-v7a", "x86", "x86_64", "arm64-v8a"]
+}
+
android {
- compileSdkVersion rootProject.ext.compileSdkVersion
+ ndkVersion rootProject.ext.ndkVersion
- compileOptions {
- sourceCompatibility JavaVersion.VERSION_1_8
- targetCompatibility JavaVersion.VERSION_1_8
- }
+ compileSdkVersion rootProject.ext.compileSdkVersion
defaultConfig {
- applicationId "com.bes"
+ applicationId "com.reactnativestarter"
minSdkVersion rootProject.ext.minSdkVersion
targetSdkVersion rootProject.ext.targetSdkVersion
- versionCode 1
- versionName "1.0"
+ versionCode 2
+ versionName "2.0"
+ buildConfigField "boolean", "IS_NEW_ARCHITECTURE_ENABLED", isNewArchitectureEnabled().toString()
+
+ if (isNewArchitectureEnabled()) {
+ // We configure the NDK build only if you decide to opt-in for the New Architecture.
+ externalNativeBuild {
+ ndkBuild {
+ arguments "APP_PLATFORM=android-21",
+ "APP_STL=c++_shared",
+ "NDK_TOOLCHAIN_VERSION=clang",
+ "GENERATED_SRC_DIR=$buildDir/generated/source",
+ "PROJECT_BUILD_DIR=$buildDir",
+ "REACT_ANDROID_DIR=$rootDir/../node_modules/react-native/ReactAndroid",
+ "REACT_ANDROID_BUILD_DIR=$rootDir/../node_modules/react-native/ReactAndroid/build"
+ cFlags "-Wall", "-Werror", "-fexceptions", "-frtti", "-DWITH_INSPECTOR=1"
+ cppFlags "-std=c++17"
+ // Make sure this target name is the same you specify inside the
+ // src/main/jni/Android.mk file for the `LOCAL_MODULE` variable.
+ targets "reactnativestarter_appmodules"
+
+ // Fix for windows limit on number of character in file paths and in command lines
+ if (Os.isFamily(Os.FAMILY_WINDOWS)) {
+ arguments "NDK_OUT=${rootProject.projectDir.getParent()}\\.cxx",
+ "NDK_APP_SHORT_COMMANDS=true"
+ }
+ }
+ }
+ if (!enableSeparateBuildPerCPUArchitecture) {
+ ndk {
+ abiFilters (*reactNativeArchitectures())
+ }
+ }
+ }
}
+
+ if (isNewArchitectureEnabled()) {
+ // We configure the NDK build only if you decide to opt-in for the New Architecture.
+ externalNativeBuild {
+ ndkBuild {
+ path "$projectDir/src/main/jni/Android.mk"
+ }
+ }
+ def reactAndroidProjectDir = project(':ReactAndroid').projectDir
+ def packageReactNdkDebugLibs = tasks.register("packageReactNdkDebugLibs", Copy) {
+ dependsOn(":ReactAndroid:packageReactNdkDebugLibsForBuck")
+ from("$reactAndroidProjectDir/src/main/jni/prebuilt/lib")
+ into("$buildDir/react-ndk/exported")
+ }
+ def packageReactNdkReleaseLibs = tasks.register("packageReactNdkReleaseLibs", Copy) {
+ dependsOn(":ReactAndroid:packageReactNdkReleaseLibsForBuck")
+ from("$reactAndroidProjectDir/src/main/jni/prebuilt/lib")
+ into("$buildDir/react-ndk/exported")
+ }
+ afterEvaluate {
+ // If you wish to add a custom TurboModule or component locally,
+ // you should uncomment this line.
+ // preBuild.dependsOn("generateCodegenArtifactsFromSchema")
+ preDebugBuild.dependsOn(packageReactNdkDebugLibs)
+ preReleaseBuild.dependsOn(packageReactNdkReleaseLibs)
+
+ // Due to a bug inside AGP, we have to explicitly set a dependency
+ // between configureNdkBuild* tasks and the preBuild tasks.
+ // This can be removed once this is solved: https://issuetracker.google.com/issues/207403732
+ configureNdkBuildRelease.dependsOn(preReleaseBuild)
+ configureNdkBuildDebug.dependsOn(preDebugBuild)
+ reactNativeArchitectures().each { architecture ->
+ tasks.findByName("configureNdkBuildDebug[${architecture}]")?.configure {
+ dependsOn("preDebugBuild")
+ }
+ tasks.findByName("configureNdkBuildRelease[${architecture}]")?.configure {
+ dependsOn("preReleaseBuild")
+ }
+ }
+ }
+ }
+
splits {
abi {
reset()
enable enableSeparateBuildPerCPUArchitecture
universalApk false // If true, also generate a universal APK
- include "armeabi-v7a", "x86", "arm64-v8a", "x86_64"
+ include (*reactNativeArchitectures())
}
}
signingConfigs {
@@ -169,11 +249,12 @@ android {
variant.outputs.each { output ->
// For each separate APK per architecture, set a unique version code as described here:
// https://developer.android.com/studio/build/configure-apk-splits.html
+ // Example: versionCode 1 will generate 1001 for armeabi-v7a, 1002 for x86, etc.
def versionCodes = ["armeabi-v7a": 1, "x86": 2, "arm64-v8a": 3, "x86_64": 4]
def abi = output.getFilter(OutputFile.ABI)
if (abi != null) { // null for the universal-debug, universal-release variants
output.versionCodeOverride =
- versionCodes.get(abi) * 1048576 + defaultConfig.versionCode
+ defaultConfig.versionCode * 1000 + versionCodes.get(abi)
}
}
@@ -182,13 +263,14 @@ android {
dependencies {
implementation fileTree(dir: "libs", include: ["*.jar"])
+
//noinspection GradleDynamicVersion
implementation "com.facebook.react:react-native:+" // From node_modules
implementation "androidx.swiperefreshlayout:swiperefreshlayout:1.0.0"
debugImplementation("com.facebook.flipper:flipper:${FLIPPER_VERSION}") {
- exclude group:'com.facebook.fbjni'
+ exclude group:'com.facebook.fbjni'
}
debugImplementation("com.facebook.flipper:flipper-network-plugin:${FLIPPER_VERSION}") {
@@ -209,11 +291,31 @@ dependencies {
}
}
+if (isNewArchitectureEnabled()) {
+ // If new architecture is enabled, we let you build RN from source
+ // Otherwise we fallback to a prebuilt .aar bundled in the NPM package.
+ // This will be applied to all the imported transtitive dependency.
+ configurations.all {
+ resolutionStrategy.dependencySubstitution {
+ substitute(module("com.facebook.react:react-native"))
+ .using(project(":ReactAndroid")).because("On New Architecture we're building React Native from source")
+ }
+ }
+}
+
// Run this once to be able to run the application with BUCK
// puts all compile dependencies into folder libs for BUCK to use
task copyDownloadableDepsToLibs(type: Copy) {
- from configurations.compile
+ from configurations.implementation
into 'libs'
}
apply from: file("../../node_modules/@react-native-community/cli-platform-android/native_modules.gradle"); applyNativeModulesAppBuildGradle(project)
+
+def isNewArchitectureEnabled() {
+ // To opt-in for the New Architecture, you can either:
+ // - Set `newArchEnabled` to true inside the `gradle.properties` file
+ // - Invoke gradle with `-newArchEnabled=true`
+ // - Set an environment variable `ORG_GRADLE_PROJECT_newArchEnabled=true`
+ return project.hasProperty("newArchEnabled") && project.newArchEnabled == "true"
+}
@@ -114,33 +115,112 @@ def jscFlavor = 'org.webkit:android-jsc:+'
* Whether to enable the Hermes VM.
*
- * This should be set on project.ext.react and mirrored here. If it is not set
+ * This should be set on project.ext.react and that value will be read here. If it is not set
* on project.ext.react, JavaScript will not be compiled to Hermes Bytecode
* and the benefits of using Hermes will therefore be sharply reduced.